import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { SFNServiceException as __BaseException } from "./SFNServiceException";
/**
 * @public
 * <p>The specified activity does not exist.</p>
 */
export declare class ActivityDoesNotExist extends __BaseException {
    readonly name: "ActivityDoesNotExist";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ActivityDoesNotExist, __BaseException>);
}
/**
 * @public
 * <p>Contains details about an activity that failed during an execution.</p>
 */
export interface ActivityFailedEventDetails {
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>The maximum number of activities has been reached. Existing activities must be deleted
 *       before a new activity can be created.</p>
 */
export declare class ActivityLimitExceeded extends __BaseException {
    readonly name: "ActivityLimitExceeded";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ActivityLimitExceeded, __BaseException>);
}
/**
 * @public
 * <p>Contains details about an activity.</p>
 */
export interface ActivityListItem {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the activity.</p>
     */
    activityArn: string | undefined;
    /**
     * @public
     * <p>The name of the activity.</p>
     *          <p>A name must <i>not</i> contain:</p>
     *          <ul>
     *             <li>
     *                <p>white space</p>
     *             </li>
     *             <li>
     *                <p>brackets <code>< > \{ \} [ ]</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>wildcard characters <code>? *</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>special characters <code>" # % \ ^ | ~ ` $ & , ; : /</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p>
     *             </li>
     *          </ul>
     *          <p>To enable logging with CloudWatch Logs, the name should only contain  0-9, A-Z, a-z, - and _.</p>
     */
    name: string | undefined;
    /**
     * @public
     * <p>The date the activity is created.</p>
     */
    creationDate: Date | undefined;
}
/**
 * @public
 * <p>Provides details about input or output in an execution history event.</p>
 */
export interface HistoryEventExecutionDataDetails {
    /**
     * @public
     * <p>Indicates whether input or output was truncated in the response. Always <code>false</code>
     *       for API calls.</p>
     */
    truncated?: boolean;
}
/**
 * @public
 * <p>Contains details about an activity scheduled during an execution.</p>
 */
export interface ActivityScheduledEventDetails {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the scheduled activity.</p>
     */
    resource: string | undefined;
    /**
     * @public
     * <p>The JSON data input to the activity task. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    input?: string;
    /**
     * @public
     * <p>Contains details about the input for an execution history event.</p>
     */
    inputDetails?: HistoryEventExecutionDataDetails;
    /**
     * @public
     * <p>The maximum allowed duration of the activity task.</p>
     */
    timeoutInSeconds?: number;
    /**
     * @public
     * <p>The maximum allowed duration between two heartbeats for the activity task.</p>
     */
    heartbeatInSeconds?: number;
}
/**
 * @public
 * <p>Contains details about an activity schedule failure that occurred during an
 *       execution.</p>
 */
export interface ActivityScheduleFailedEventDetails {
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>Contains details about the start of an activity during an execution.</p>
 */
export interface ActivityStartedEventDetails {
    /**
     * @public
     * <p>The name of the worker that the task is assigned to. These names are provided by the
     *       workers when calling <a>GetActivityTask</a>.</p>
     */
    workerName?: string;
}
/**
 * @public
 * <p>Contains details about an activity that successfully terminated during an
 *       execution.</p>
 */
export interface ActivitySucceededEventDetails {
    /**
     * @public
     * <p>The JSON data output by the activity task. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    output?: string;
    /**
     * @public
     * <p>Contains details about the output of an execution history event.</p>
     */
    outputDetails?: HistoryEventExecutionDataDetails;
}
/**
 * @public
 * <p>Contains details about an activity timeout that occurred during an execution.</p>
 */
export interface ActivityTimedOutEventDetails {
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the timeout.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>The maximum number of workers concurrently polling for activity tasks has been
 *       reached.</p>
 */
export declare class ActivityWorkerLimitExceeded extends __BaseException {
    readonly name: "ActivityWorkerLimitExceeded";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ActivityWorkerLimitExceeded, __BaseException>);
}
/**
 * @public
 * <p>Tags are key-value pairs that can be associated with Step Functions state machines and
 *       activities.</p>
 *          <p>An array of key-value pairs. For more information, see <a href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html">Using
 *       Cost Allocation Tags</a> in the <i>Amazon Web Services Billing and Cost Management User
 *         Guide</i>, and <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_iam-tags.html">Controlling Access Using IAM
 *           Tags</a>.</p>
 *          <p>Tags may only contain Unicode letters, digits, white space, or these symbols: <code>_ . : / = + - @</code>.</p>
 */
export interface Tag {
    /**
     * @public
     * <p>The key of a tag.</p>
     */
    key?: string;
    /**
     * @public
     * <p>The value of a tag.</p>
     */
    value?: string;
}
/**
 * @public
 */
export interface CreateActivityInput {
    /**
     * @public
     * <p>The name of the activity to create. This name must be unique for your Amazon Web Services account and region for 90 days. For more information,
     *     see <a href="https://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions">
     *     Limits Related to State Machine Executions</a> in the <i>Step Functions Developer Guide</i>.</p>
     *          <p>A name must <i>not</i> contain:</p>
     *          <ul>
     *             <li>
     *                <p>white space</p>
     *             </li>
     *             <li>
     *                <p>brackets <code>< > \{ \} [ ]</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>wildcard characters <code>? *</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>special characters <code>" # % \ ^ | ~ ` $ & , ; : /</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p>
     *             </li>
     *          </ul>
     *          <p>To enable logging with CloudWatch Logs, the name should only contain  0-9, A-Z, a-z, - and _.</p>
     */
    name: string | undefined;
    /**
     * @public
     * <p>The list of tags to add to a resource.</p>
     *          <p>An array of key-value pairs. For more information, see <a href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html">Using
     *       Cost Allocation Tags</a> in the <i>Amazon Web Services Billing and Cost Management User
     *         Guide</i>, and <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_iam-tags.html">Controlling Access Using IAM
     *           Tags</a>.</p>
     *          <p>Tags may only contain Unicode letters, digits, white space, or these symbols: <code>_ . : / = + - @</code>.</p>
     */
    tags?: Tag[];
}
/**
 * @public
 */
export interface CreateActivityOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the created activity.</p>
     */
    activityArn: string | undefined;
    /**
     * @public
     * <p>The date the activity is created.</p>
     */
    creationDate: Date | undefined;
}
/**
 * @public
 * <p>The provided name is not valid.</p>
 */
export declare class InvalidName extends __BaseException {
    readonly name: "InvalidName";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidName, __BaseException>);
}
/**
 * @public
 * <p>You've exceeded the number of tags allowed for a resource. See the <a href="https://docs.aws.amazon.com/step-functions/latest/dg/limits.html"> Limits Topic</a> in the
 *       Step Functions Developer Guide.</p>
 */
export declare class TooManyTags extends __BaseException {
    readonly name: "TooManyTags";
    readonly $fault: "client";
    resourceName?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<TooManyTags, __BaseException>);
}
/**
 * @public
 * <p>Updating or deleting a resource can cause an inconsistent state. This error occurs when there're concurrent requests for <a>DeleteStateMachineVersion</a>, <a>PublishStateMachineVersion</a>, or <a>UpdateStateMachine</a> with the <code>publish</code> parameter set to <code>true</code>.</p>
 *          <p>HTTP Status Code: 409</p>
 */
export declare class ConflictException extends __BaseException {
    readonly name: "ConflictException";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
/**
 * @public
 * <p></p>
 */
export interface CloudWatchLogsLogGroup {
    /**
     * @public
     * <p>The ARN of the the CloudWatch log group to which you want your logs emitted to. The ARN
     *       must end with <code>:*</code>
     *          </p>
     */
    logGroupArn?: string;
}
/**
 * @public
 * <p></p>
 */
export interface LogDestination {
    /**
     * @public
     * <p>An object describing a CloudWatch log group. For more information, see <a href="https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-logs-loggroup.html">AWS::Logs::LogGroup</a> in the CloudFormation User Guide.</p>
     */
    cloudWatchLogsLogGroup?: CloudWatchLogsLogGroup;
}
/**
 * @public
 * @enum
 */
export declare const LogLevel: {
    readonly ALL: "ALL";
    readonly ERROR: "ERROR";
    readonly FATAL: "FATAL";
    readonly OFF: "OFF";
};
/**
 * @public
 */
export type LogLevel = (typeof LogLevel)[keyof typeof LogLevel];
/**
 * @public
 * <p>The <code>LoggingConfiguration</code> data type is used to set CloudWatch Logs
 *       options.</p>
 */
export interface LoggingConfiguration {
    /**
     * @public
     * <p>Defines which category of execution history events are logged.</p>
     */
    level?: LogLevel;
    /**
     * @public
     * <p>Determines whether execution data is included in your log. When set to <code>false</code>,
     *       data is excluded.</p>
     */
    includeExecutionData?: boolean;
    /**
     * @public
     * <p>An array of objects that describes where your execution history events will be logged.
     *       Limited to size 1. Required, if your log level is not set to <code>OFF</code>.</p>
     */
    destinations?: LogDestination[];
}
/**
 * @public
 * <p>Selects whether or not the state machine's X-Ray tracing is enabled. Default is
 *         <code>false</code>
 *          </p>
 */
export interface TracingConfiguration {
    /**
     * @public
     * <p>When set to <code>true</code>, X-Ray tracing is enabled.</p>
     */
    enabled?: boolean;
}
/**
 * @public
 * @enum
 */
export declare const StateMachineType: {
    readonly EXPRESS: "EXPRESS";
    readonly STANDARD: "STANDARD";
};
/**
 * @public
 */
export type StateMachineType = (typeof StateMachineType)[keyof typeof StateMachineType];
/**
 * @public
 */
export interface CreateStateMachineInput {
    /**
     * @public
     * <p>The name of the state machine. </p>
     *          <p>A name must <i>not</i> contain:</p>
     *          <ul>
     *             <li>
     *                <p>white space</p>
     *             </li>
     *             <li>
     *                <p>brackets <code>< > \{ \} [ ]</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>wildcard characters <code>? *</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>special characters <code>" # % \ ^ | ~ ` $ & , ; : /</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p>
     *             </li>
     *          </ul>
     *          <p>To enable logging with CloudWatch Logs, the name should only contain  0-9, A-Z, a-z, - and _.</p>
     */
    name: string | undefined;
    /**
     * @public
     * <p>The Amazon States Language definition of the state machine. See <a href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-amazon-states-language.html">Amazon States Language</a>.</p>
     */
    definition: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role to use for this state machine.</p>
     */
    roleArn: string | undefined;
    /**
     * @public
     * <p>Determines whether a Standard or Express state machine is created. The default is
     *         <code>STANDARD</code>. You cannot update the <code>type</code> of a state machine once it
     *       has been created.</p>
     */
    type?: StateMachineType;
    /**
     * @public
     * <p>Defines what execution history events are logged and where they are logged.</p>
     *          <note>
     *             <p>By default, the <code>level</code> is set to <code>OFF</code>. For more information see
     *           <a href="https://docs.aws.amazon.com/step-functions/latest/dg/cloudwatch-log-level.html">Log
     *           Levels</a> in the Step Functions User Guide.</p>
     *          </note>
     */
    loggingConfiguration?: LoggingConfiguration;
    /**
     * @public
     * <p>Tags to be added when creating a state machine.</p>
     *          <p>An array of key-value pairs. For more information, see <a href="https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html">Using
     *       Cost Allocation Tags</a> in the <i>Amazon Web Services Billing and Cost Management User
     *         Guide</i>, and <a href="https://docs.aws.amazon.com/IAM/latest/UserGuide/access_iam-tags.html">Controlling Access Using IAM
     *           Tags</a>.</p>
     *          <p>Tags may only contain Unicode letters, digits, white space, or these symbols: <code>_ . : / = + - @</code>.</p>
     */
    tags?: Tag[];
    /**
     * @public
     * <p>Selects whether X-Ray tracing is enabled.</p>
     */
    tracingConfiguration?: TracingConfiguration;
    /**
     * @public
     * <p>Set to <code>true</code> to publish the first version of the state machine during creation. The default is <code>false</code>.</p>
     */
    publish?: boolean;
    /**
     * @public
     * <p>Sets description about the state machine version. You can only set the description if the <code>publish</code> parameter is set to <code>true</code>. Otherwise, if you set <code>versionDescription</code>, but <code>publish</code> to <code>false</code>, this API action throws <code>ValidationException</code>.</p>
     */
    versionDescription?: string;
}
/**
 * @public
 */
export interface CreateStateMachineOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the created state machine.</p>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>The date the state machine is created.</p>
     */
    creationDate: Date | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the created state machine version. If you do not set the <code>publish</code> parameter to <code>true</code>, this field returns null value.</p>
     */
    stateMachineVersionArn?: string;
}
/**
 * @public
 * <p>The provided Amazon Resource Name (ARN) is not valid.</p>
 */
export declare class InvalidArn extends __BaseException {
    readonly name: "InvalidArn";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidArn, __BaseException>);
}
/**
 * @public
 * <p>The provided Amazon States Language definition is not valid.</p>
 */
export declare class InvalidDefinition extends __BaseException {
    readonly name: "InvalidDefinition";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidDefinition, __BaseException>);
}
/**
 * @public
 * <p></p>
 */
export declare class InvalidLoggingConfiguration extends __BaseException {
    readonly name: "InvalidLoggingConfiguration";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidLoggingConfiguration, __BaseException>);
}
/**
 * @public
 * <p>Your <code>tracingConfiguration</code> key does not match, or <code>enabled</code> has not
 *       been set to <code>true</code> or <code>false</code>.</p>
 */
export declare class InvalidTracingConfiguration extends __BaseException {
    readonly name: "InvalidTracingConfiguration";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidTracingConfiguration, __BaseException>);
}
/**
 * @public
 * <p>A state machine with the same name but a different definition or role ARN already
 *       exists.</p>
 */
export declare class StateMachineAlreadyExists extends __BaseException {
    readonly name: "StateMachineAlreadyExists";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<StateMachineAlreadyExists, __BaseException>);
}
/**
 * @public
 * <p>The specified state machine is being deleted.</p>
 */
export declare class StateMachineDeleting extends __BaseException {
    readonly name: "StateMachineDeleting";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<StateMachineDeleting, __BaseException>);
}
/**
 * @public
 * <p>The maximum number of state machines has been reached. Existing state machines must be
 *       deleted before a new state machine can be created.</p>
 */
export declare class StateMachineLimitExceeded extends __BaseException {
    readonly name: "StateMachineLimitExceeded";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<StateMachineLimitExceeded, __BaseException>);
}
/**
 * @public
 * <p></p>
 */
export declare class StateMachineTypeNotSupported extends __BaseException {
    readonly name: "StateMachineTypeNotSupported";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<StateMachineTypeNotSupported, __BaseException>);
}
/**
 * @public
 * @enum
 */
export declare const ValidationExceptionReason: {
    readonly API_DOES_NOT_SUPPORT_LABELED_ARNS: "API_DOES_NOT_SUPPORT_LABELED_ARNS";
    readonly CANNOT_UPDATE_COMPLETED_MAP_RUN: "CANNOT_UPDATE_COMPLETED_MAP_RUN";
    readonly INVALID_ROUTING_CONFIGURATION: "INVALID_ROUTING_CONFIGURATION";
    readonly MISSING_REQUIRED_PARAMETER: "MISSING_REQUIRED_PARAMETER";
};
/**
 * @public
 */
export type ValidationExceptionReason = (typeof ValidationExceptionReason)[keyof typeof ValidationExceptionReason];
/**
 * @public
 * <p>The input does not satisfy the constraints specified by an Amazon Web Services service.</p>
 */
export declare class ValidationException extends __BaseException {
    readonly name: "ValidationException";
    readonly $fault: "client";
    /**
     * @public
     * <p>The input does not satisfy the constraints specified by an Amazon Web Services service.</p>
     */
    reason?: ValidationExceptionReason;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ValidationException, __BaseException>);
}
/**
 * @public
 * <p>Contains details about the routing configuration of a state machine alias. In a routing
 *       configuration, you define an array of objects that specify up to two state machine versions.
 *       You also specify the percentage of traffic to be routed to each version.</p>
 */
export interface RoutingConfigurationListItem {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies one or two state machine versions defined in the routing configuration.</p>
     *          <p>If you specify the ARN of a second version, it must belong to the same state machine as the first version.</p>
     */
    stateMachineVersionArn: string | undefined;
    /**
     * @public
     * <p>The percentage of traffic you want to route to a state machine
     *       version. The sum of the weights in the routing
     *       configuration must be equal to 100.</p>
     */
    weight: number | undefined;
}
/**
 * @public
 */
export interface CreateStateMachineAliasInput {
    /**
     * @public
     * <p>A description for the state machine alias.</p>
     */
    description?: string;
    /**
     * @public
     * <p>The name of the state machine alias.</p>
     *          <p>To avoid conflict with version ARNs, don't use an integer in the name of the alias.</p>
     */
    name: string | undefined;
    /**
     * @public
     * <p>The routing configuration of a state machine alias. The routing configuration shifts
     *       execution traffic between two state machine versions. <code>routingConfiguration</code>
     *       contains an array of <code>RoutingConfig</code> objects that specify up to two state machine
     *       versions. Step Functions then randomly choses which version to run an execution with based
     *       on the weight assigned to each <code>RoutingConfig</code>.</p>
     */
    routingConfiguration: RoutingConfigurationListItem[] | undefined;
}
/**
 * @public
 */
export interface CreateStateMachineAliasOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the created state machine alias.</p>
     */
    stateMachineAliasArn: string | undefined;
    /**
     * @public
     * <p>The date the state machine alias was created.</p>
     */
    creationDate: Date | undefined;
}
/**
 * @public
 * <p>Could not find the referenced resource.</p>
 */
export declare class ResourceNotFound extends __BaseException {
    readonly name: "ResourceNotFound";
    readonly $fault: "client";
    resourceName?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ResourceNotFound, __BaseException>);
}
/**
 * @public
 * <p>The request would cause a service quota to be exceeded.</p>
 *          <p>HTTP Status Code: 402</p>
 */
export declare class ServiceQuotaExceededException extends __BaseException {
    readonly name: "ServiceQuotaExceededException";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>);
}
/**
 * @public
 */
export interface DeleteActivityInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the activity to delete.</p>
     */
    activityArn: string | undefined;
}
/**
 * @public
 */
export interface DeleteActivityOutput {
}
/**
 * @public
 */
export interface DeleteStateMachineInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine to delete.</p>
     */
    stateMachineArn: string | undefined;
}
/**
 * @public
 */
export interface DeleteStateMachineOutput {
}
/**
 * @public
 */
export interface DeleteStateMachineAliasInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine alias to delete.</p>
     */
    stateMachineAliasArn: string | undefined;
}
/**
 * @public
 */
export interface DeleteStateMachineAliasOutput {
}
/**
 * @public
 */
export interface DeleteStateMachineVersionInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine version to delete.</p>
     */
    stateMachineVersionArn: string | undefined;
}
/**
 * @public
 */
export interface DeleteStateMachineVersionOutput {
}
/**
 * @public
 */
export interface DescribeActivityInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the activity to describe.</p>
     */
    activityArn: string | undefined;
}
/**
 * @public
 */
export interface DescribeActivityOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the activity.</p>
     */
    activityArn: string | undefined;
    /**
     * @public
     * <p>The name of the activity.</p>
     *          <p>A name must <i>not</i> contain:</p>
     *          <ul>
     *             <li>
     *                <p>white space</p>
     *             </li>
     *             <li>
     *                <p>brackets <code>< > \{ \} [ ]</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>wildcard characters <code>? *</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>special characters <code>" # % \ ^ | ~ ` $ & , ; : /</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p>
     *             </li>
     *          </ul>
     *          <p>To enable logging with CloudWatch Logs, the name should only contain  0-9, A-Z, a-z, - and _.</p>
     */
    name: string | undefined;
    /**
     * @public
     * <p>The date the activity is created.</p>
     */
    creationDate: Date | undefined;
}
/**
 * @public
 */
export interface DescribeExecutionInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the execution to describe.</p>
     */
    executionArn: string | undefined;
}
/**
 * @public
 * <p>Provides details about execution input or output.</p>
 */
export interface CloudWatchEventsExecutionDataDetails {
    /**
     * @public
     * <p>Indicates whether input or output was included in the response. Always <code>true</code>
     *       for API calls. </p>
     */
    included?: boolean;
}
/**
 * @public
 * @enum
 */
export declare const ExecutionRedriveStatus: {
    readonly NOT_REDRIVABLE: "NOT_REDRIVABLE";
    readonly REDRIVABLE: "REDRIVABLE";
    readonly REDRIVABLE_BY_MAP_RUN: "REDRIVABLE_BY_MAP_RUN";
};
/**
 * @public
 */
export type ExecutionRedriveStatus = (typeof ExecutionRedriveStatus)[keyof typeof ExecutionRedriveStatus];
/**
 * @public
 * @enum
 */
export declare const ExecutionStatus: {
    readonly ABORTED: "ABORTED";
    readonly FAILED: "FAILED";
    readonly PENDING_REDRIVE: "PENDING_REDRIVE";
    readonly RUNNING: "RUNNING";
    readonly SUCCEEDED: "SUCCEEDED";
    readonly TIMED_OUT: "TIMED_OUT";
};
/**
 * @public
 */
export type ExecutionStatus = (typeof ExecutionStatus)[keyof typeof ExecutionStatus];
/**
 * @public
 */
export interface DescribeExecutionOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the execution.</p>
     */
    executionArn: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the executed stated machine.</p>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>The name of the execution.</p>
     *          <p>A name must <i>not</i> contain:</p>
     *          <ul>
     *             <li>
     *                <p>white space</p>
     *             </li>
     *             <li>
     *                <p>brackets <code>< > \{ \} [ ]</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>wildcard characters <code>? *</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>special characters <code>" # % \ ^ | ~ ` $ & , ; : /</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p>
     *             </li>
     *          </ul>
     *          <p>To enable logging with CloudWatch Logs, the name should only contain  0-9, A-Z, a-z, - and _.</p>
     */
    name?: string;
    /**
     * @public
     * <p>The current status of the execution.</p>
     */
    status: ExecutionStatus | undefined;
    /**
     * @public
     * <p>The date the execution is started.</p>
     */
    startDate: Date | undefined;
    /**
     * @public
     * <p>If the execution ended, the date the execution stopped.</p>
     */
    stopDate?: Date;
    /**
     * @public
     * <p>The string that contains the JSON input data of the execution. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    input?: string;
    /**
     * @public
     * <p>Provides details about execution input or output.</p>
     */
    inputDetails?: CloudWatchEventsExecutionDataDetails;
    /**
     * @public
     * <p>The JSON output data of the execution. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     *          <note>
     *             <p>This field is set only if the execution succeeds. If the execution fails, this field is
     *         null.</p>
     *          </note>
     */
    output?: string;
    /**
     * @public
     * <p>Provides details about execution input or output.</p>
     */
    outputDetails?: CloudWatchEventsExecutionDataDetails;
    /**
     * @public
     * <p>The X-Ray trace header that was passed to the execution.</p>
     */
    traceHeader?: string;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies a Map Run, which dispatched this execution.</p>
     */
    mapRunArn?: string;
    /**
     * @public
     * <p>The error string if the state machine execution failed.</p>
     */
    error?: string;
    /**
     * @public
     * <p>The cause string if the state machine execution failed.</p>
     */
    cause?: string;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine version associated with the execution. The version ARN is a combination of state machine ARN and the version number separated by a colon (:). For example, <code>stateMachineARN:1</code>.</p>
     *          <p>If you start an execution from a <code>StartExecution</code> request without specifying a
     *       state machine version or alias ARN, Step Functions returns a null value.</p>
     */
    stateMachineVersionArn?: string;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine alias associated with the execution. The alias ARN is a combination of state machine ARN and the alias name separated by a colon (:). For example, <code>stateMachineARN:PROD</code>.</p>
     *          <p>If you start an execution from a <code>StartExecution</code> request with a
     *       state machine version ARN, this field will be null.</p>
     */
    stateMachineAliasArn?: string;
    /**
     * @public
     * <p>The number of times you've redriven an execution. If you have not yet redriven an execution, the <code>redriveCount</code> is 0. This count is only updated if you successfully redrive an execution.</p>
     */
    redriveCount?: number;
    /**
     * @public
     * <p>The date the execution was last redriven. If you have not yet redriven an execution, the <code>redriveDate</code> is null.</p>
     *          <p>The <code>redriveDate</code> is unavailable if you redrive a Map Run that starts child workflow executions of type <code>EXPRESS</code>.</p>
     */
    redriveDate?: Date;
    /**
     * @public
     * <p>Indicates whether or not an execution can be redriven at a given point in time.</p>
     *          <ul>
     *             <li>
     *                <p>For executions of type <code>STANDARD</code>, <code>redriveStatus</code> is <code>NOT_REDRIVABLE</code> if calling the <a>RedriveExecution</a> API action would return the <code>ExecutionNotRedrivable</code> error.</p>
     *             </li>
     *             <li>
     *                <p>For a Distributed Map that includes child workflows of type <code>STANDARD</code>, <code>redriveStatus</code> indicates whether or not the Map Run can redrive child workflow executions.</p>
     *             </li>
     *             <li>
     *                <p>For a Distributed Map that includes child workflows of type <code>EXPRESS</code>, <code>redriveStatus</code> indicates whether or not the Map Run can redrive child workflow executions.</p>
     *                <p>You can redrive failed or timed out <code>EXPRESS</code> workflows <i>only if</i> they're a part of a Map Run. When you <a href="https://docs.aws.amazon.com/step-functions/latest/dg/redrive-map-run.html">redrive</a> the Map Run, these workflows are restarted using the <a>StartExecution</a> API action.</p>
     *             </li>
     *          </ul>
     */
    redriveStatus?: ExecutionRedriveStatus;
    /**
     * @public
     * <p>When <code>redriveStatus</code> is <code>NOT_REDRIVABLE</code>, <code>redriveStatusReason</code> specifies the reason why an execution cannot be redriven.</p>
     *          <ul>
     *             <li>
     *                <p>For executions of type <code>STANDARD</code>, or for a Distributed Map that includes child workflows of type <code>STANDARD</code>, <code>redriveStatusReason</code> can include one of the following reasons:</p>
     *                <ul>
     *                   <li>
     *                      <p>
     *                         <code>State machine is in DELETING status</code>.</p>
     *                   </li>
     *                   <li>
     *                      <p>
     *                         <code>Execution is RUNNING and cannot be redriven</code>.</p>
     *                   </li>
     *                   <li>
     *                      <p>
     *                         <code>Execution is SUCCEEDED and cannot be redriven</code>.</p>
     *                   </li>
     *                   <li>
     *                      <p>
     *                         <code>Execution was started before the launch of RedriveExecution</code>.</p>
     *                   </li>
     *                   <li>
     *                      <p>
     *                         <code>Execution history event limit exceeded</code>.</p>
     *                   </li>
     *                   <li>
     *                      <p>
     *                         <code>Execution has exceeded the max execution time</code>.</p>
     *                   </li>
     *                   <li>
     *                      <p>
     *                         <code>Execution redrivable period exceeded</code>.</p>
     *                   </li>
     *                </ul>
     *             </li>
     *             <li>
     *                <p>For a Distributed Map that includes child workflows of type <code>EXPRESS</code>, <code>redriveStatusReason</code> is only returned if the child workflows are not redrivable. This happens when the child workflow executions have completed successfully.</p>
     *             </li>
     *          </ul>
     */
    redriveStatusReason?: string;
}
/**
 * @public
 * <p>The specified execution does not exist.</p>
 */
export declare class ExecutionDoesNotExist extends __BaseException {
    readonly name: "ExecutionDoesNotExist";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ExecutionDoesNotExist, __BaseException>);
}
/**
 * @public
 */
export interface DescribeMapRunInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies a Map Run.</p>
     */
    mapRunArn: string | undefined;
}
/**
 * @public
 * <p>Contains details about all of the child workflow executions started by a Map Run.</p>
 */
export interface MapRunExecutionCounts {
    /**
     * @public
     * <p>The total number of child workflow executions that were started by a Map Run, but haven't started executing yet. </p>
     */
    pending: number | undefined;
    /**
     * @public
     * <p>The total number of child workflow executions that were started by a Map Run and are currently in-progress.</p>
     */
    running: number | undefined;
    /**
     * @public
     * <p>The total number of child workflow executions that were started by a Map Run and have completed successfully.</p>
     */
    succeeded: number | undefined;
    /**
     * @public
     * <p>The total number of child workflow executions that were started by a Map Run, but have failed.</p>
     */
    failed: number | undefined;
    /**
     * @public
     * <p>The total number of child workflow executions that were started by a Map Run and have timed out.</p>
     */
    timedOut: number | undefined;
    /**
     * @public
     * <p>The total number of child workflow executions that were started by a Map Run and were running, but were either stopped by the user or by Step Functions because the Map Run failed. </p>
     */
    aborted: number | undefined;
    /**
     * @public
     * <p>The total number of child workflow executions that were started by a Map Run.</p>
     */
    total: number | undefined;
    /**
     * @public
     * <p>Returns the count of child workflow executions whose results were written by <code>ResultWriter</code>. For more information, see <a href="https://docs.aws.amazon.com/step-functions/latest/dg/input-output-resultwriter.html">ResultWriter</a> in the <i>Step Functions Developer Guide</i>.</p>
     */
    resultsWritten: number | undefined;
    /**
     * @public
     * <p>The number of <code>FAILED</code>, <code>ABORTED</code>, or <code>TIMED_OUT</code> child workflow executions that cannot be redriven because their execution status is terminal. For example, child workflows with an execution status of <code>FAILED</code>, <code>ABORTED</code>, or <code>TIMED_OUT</code> and a <code>redriveStatus</code> of <code>NOT_REDRIVABLE</code>.</p>
     */
    failuresNotRedrivable?: number;
    /**
     * @public
     * <p>The number of unsuccessful child workflow executions currently waiting to be redriven. The status of these child workflow executions could be <code>FAILED</code>, <code>ABORTED</code>, or <code>TIMED_OUT</code> in the original execution attempt or a previous redrive attempt.</p>
     */
    pendingRedrive?: number;
}
/**
 * @public
 * <p>Contains details about items that were processed in all of the child workflow executions that were started by a Map Run.</p>
 */
export interface MapRunItemCounts {
    /**
     * @public
     * <p>The total number of items to process in child workflow executions that haven't started running yet.</p>
     */
    pending: number | undefined;
    /**
     * @public
     * <p>The total number of items being processed in child workflow executions that are currently in-progress.</p>
     */
    running: number | undefined;
    /**
     * @public
     * <p>The total number of items processed in child workflow executions that have completed successfully.</p>
     */
    succeeded: number | undefined;
    /**
     * @public
     * <p>The total number of items processed in child workflow executions that have failed.</p>
     */
    failed: number | undefined;
    /**
     * @public
     * <p>The total number of items processed in child workflow executions that have timed out.</p>
     */
    timedOut: number | undefined;
    /**
     * @public
     * <p>The total number of items processed in child workflow executions that were either stopped by the user or by Step Functions, because the Map Run failed.</p>
     */
    aborted: number | undefined;
    /**
     * @public
     * <p>The total number of items processed in all the child workflow executions started by a Map Run.</p>
     */
    total: number | undefined;
    /**
     * @public
     * <p>Returns the count of items whose results were written by <code>ResultWriter</code>. For more information, see <a href="https://docs.aws.amazon.com/step-functions/latest/dg/input-output-resultwriter.html">ResultWriter</a> in the <i>Step Functions Developer Guide</i>.</p>
     */
    resultsWritten: number | undefined;
    /**
     * @public
     * <p>The number of <code>FAILED</code>, <code>ABORTED</code>, or <code>TIMED_OUT</code> items in child workflow executions that cannot be redriven because the execution status of those child workflows is terminal. For example, child workflows with an execution status of <code>FAILED</code>, <code>ABORTED</code>, or <code>TIMED_OUT</code> and a <code>redriveStatus</code> of <code>NOT_REDRIVABLE</code>.</p>
     */
    failuresNotRedrivable?: number;
    /**
     * @public
     * <p>The number of unsuccessful items in child workflow executions currently waiting to be redriven.</p>
     */
    pendingRedrive?: number;
}
/**
 * @public
 * @enum
 */
export declare const MapRunStatus: {
    readonly ABORTED: "ABORTED";
    readonly FAILED: "FAILED";
    readonly RUNNING: "RUNNING";
    readonly SUCCEEDED: "SUCCEEDED";
};
/**
 * @public
 */
export type MapRunStatus = (typeof MapRunStatus)[keyof typeof MapRunStatus];
/**
 * @public
 */
export interface DescribeMapRunOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies a Map Run.</p>
     */
    mapRunArn: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the execution in which the Map Run was started.</p>
     */
    executionArn: string | undefined;
    /**
     * @public
     * <p>The current status of the Map Run.</p>
     */
    status: MapRunStatus | undefined;
    /**
     * @public
     * <p>The date when the Map Run was started.</p>
     */
    startDate: Date | undefined;
    /**
     * @public
     * <p>The date when the Map Run was stopped.</p>
     */
    stopDate?: Date;
    /**
     * @public
     * <p>The maximum number of child workflow executions configured to run in parallel for the Map Run at the same time.</p>
     */
    maxConcurrency: number | undefined;
    /**
     * @public
     * <p>The maximum percentage of failed child workflow executions before the Map Run fails.</p>
     */
    toleratedFailurePercentage: number | undefined;
    /**
     * @public
     * <p>The maximum number of failed child workflow executions before the Map Run fails.</p>
     */
    toleratedFailureCount: number | undefined;
    /**
     * @public
     * <p>A JSON object that contains information about the total number of items, and the item count for each processing status, such as <code>pending</code> and <code>failed</code>.</p>
     */
    itemCounts: MapRunItemCounts | undefined;
    /**
     * @public
     * <p>A JSON object that contains information about the total number of child workflow executions for the Map Run, and the count of child workflow executions for each status, such as <code>failed</code> and <code>succeeded</code>.</p>
     */
    executionCounts: MapRunExecutionCounts | undefined;
    /**
     * @public
     * <p>The number of times you've redriven a Map Run. If you have not yet redriven a Map Run, the <code>redriveCount</code> is 0. This count is only updated if you successfully redrive a Map Run.</p>
     */
    redriveCount?: number;
    /**
     * @public
     * <p>The date a Map Run was last redriven. If you have not yet redriven a Map Run, the <code>redriveDate</code> is null.</p>
     */
    redriveDate?: Date;
}
/**
 * @public
 */
export interface DescribeStateMachineInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine for which you want the information.</p>
     *          <p>If you specify a state machine version ARN, this API returns details about that version. The version ARN is a combination of state machine ARN and the version number separated by a colon (:). For example, <code>stateMachineARN:1</code>.</p>
     */
    stateMachineArn: string | undefined;
}
/**
 * @public
 * @enum
 */
export declare const StateMachineStatus: {
    readonly ACTIVE: "ACTIVE";
    readonly DELETING: "DELETING";
};
/**
 * @public
 */
export type StateMachineStatus = (typeof StateMachineStatus)[keyof typeof StateMachineStatus];
/**
 * @public
 */
export interface DescribeStateMachineOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the state machine.</p>
     *          <p>If you specified a state machine version ARN in your request, the API returns the version ARN. The version ARN is a combination of state machine ARN and the version number separated by a colon (:). For example, <code>stateMachineARN:1</code>.</p>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>The name of the state machine.</p>
     *          <p>A name must <i>not</i> contain:</p>
     *          <ul>
     *             <li>
     *                <p>white space</p>
     *             </li>
     *             <li>
     *                <p>brackets <code>< > \{ \} [ ]</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>wildcard characters <code>? *</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>special characters <code>" # % \ ^ | ~ ` $ & , ; : /</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p>
     *             </li>
     *          </ul>
     *          <p>To enable logging with CloudWatch Logs, the name should only contain  0-9, A-Z, a-z, - and _.</p>
     */
    name: string | undefined;
    /**
     * @public
     * <p>The current status of the state machine.</p>
     */
    status?: StateMachineStatus;
    /**
     * @public
     * <p>The Amazon States Language definition of the state machine. See <a href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-amazon-states-language.html">Amazon States Language</a>.</p>
     */
    definition: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role used when creating this state machine. (The IAM role
     *       maintains security by granting Step Functions access to Amazon Web Services resources.)</p>
     */
    roleArn: string | undefined;
    /**
     * @public
     * <p>The <code>type</code> of the state machine (<code>STANDARD</code> or
     *       <code>EXPRESS</code>).</p>
     */
    type: StateMachineType | undefined;
    /**
     * @public
     * <p>The date the state machine is created.</p>
     *          <p>For a state machine version, <code>creationDate</code> is the date the version was created.</p>
     */
    creationDate: Date | undefined;
    /**
     * @public
     * <p>The <code>LoggingConfiguration</code> data type is used to set CloudWatch Logs
     *       options.</p>
     */
    loggingConfiguration?: LoggingConfiguration;
    /**
     * @public
     * <p>Selects whether X-Ray tracing is enabled.</p>
     */
    tracingConfiguration?: TracingConfiguration;
    /**
     * @public
     * <p>A user-defined or an auto-generated string that identifies a <code>Map</code> state. This parameter is present only if the <code>stateMachineArn</code> specified in input is a qualified state machine ARN.</p>
     */
    label?: string;
    /**
     * @public
     * <p>The revision identifier for the state machine.</p>
     *          <p>Use the <code>revisionId</code> parameter to compare between versions of a state machine
     *       configuration used for executions without performing a diff of the properties, such as
     *         <code>definition</code> and <code>roleArn</code>.</p>
     */
    revisionId?: string;
    /**
     * @public
     * <p>The description of the state machine version.</p>
     */
    description?: string;
}
/**
 * @public
 * <p>The specified state machine does not exist.</p>
 */
export declare class StateMachineDoesNotExist extends __BaseException {
    readonly name: "StateMachineDoesNotExist";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<StateMachineDoesNotExist, __BaseException>);
}
/**
 * @public
 */
export interface DescribeStateMachineAliasInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine alias.</p>
     */
    stateMachineAliasArn: string | undefined;
}
/**
 * @public
 */
export interface DescribeStateMachineAliasOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine alias.</p>
     */
    stateMachineAliasArn?: string;
    /**
     * @public
     * <p>The name of the state machine alias.</p>
     */
    name?: string;
    /**
     * @public
     * <p>A description of the alias.</p>
     */
    description?: string;
    /**
     * @public
     * <p>The routing configuration of the alias.</p>
     */
    routingConfiguration?: RoutingConfigurationListItem[];
    /**
     * @public
     * <p>The date the state machine alias was created.</p>
     */
    creationDate?: Date;
    /**
     * @public
     * <p>The date the state machine alias was last updated.</p>
     *          <p>For a newly created state machine, this is the same as the creation date.</p>
     */
    updateDate?: Date;
}
/**
 * @public
 */
export interface DescribeStateMachineForExecutionInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the execution you want state machine information for.</p>
     */
    executionArn: string | undefined;
}
/**
 * @public
 */
export interface DescribeStateMachineForExecutionOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine associated with the execution.</p>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>The name of the state machine associated with the execution.</p>
     */
    name: string | undefined;
    /**
     * @public
     * <p>The Amazon States Language definition of the state machine. See <a href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-amazon-states-language.html">Amazon States Language</a>.</p>
     */
    definition: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role of the State Machine for the execution. </p>
     */
    roleArn: string | undefined;
    /**
     * @public
     * <p>The date and time the state machine associated with an execution was updated. For a newly
     *       created state machine, this is the creation date.</p>
     */
    updateDate: Date | undefined;
    /**
     * @public
     * <p>The <code>LoggingConfiguration</code> data type is used to set CloudWatch Logs
     *       options.</p>
     */
    loggingConfiguration?: LoggingConfiguration;
    /**
     * @public
     * <p>Selects whether X-Ray tracing is enabled.</p>
     */
    tracingConfiguration?: TracingConfiguration;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Map Run that started the child workflow execution. This field is returned only if the <code>executionArn</code> is a child workflow execution that was started by a Distributed Map state.</p>
     */
    mapRunArn?: string;
    /**
     * @public
     * <p>A user-defined or an auto-generated string that identifies a <code>Map</code> state. This ﬁeld is returned only if the <code>executionArn</code> is a child workflow execution that was started by a Distributed Map state.</p>
     */
    label?: string;
    /**
     * @public
     * <p>The revision identifier for the state machine. The first revision ID when you create the state machine is null.</p>
     *          <p>Use the state machine <code>revisionId</code> parameter to compare the revision of a state machine with the configuration of the state machine used for executions without performing a diff of the properties, such as <code>definition</code> and <code>roleArn</code>.</p>
     */
    revisionId?: string;
}
/**
 * @public
 */
export interface GetActivityTaskInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the activity to retrieve tasks from (assigned when you create the task
     *       using <a>CreateActivity</a>.)</p>
     */
    activityArn: string | undefined;
    /**
     * @public
     * <p>You can provide an arbitrary name in order to identify the worker that the task is
     *       assigned to. This name is used when it is logged in the execution history.</p>
     */
    workerName?: string;
}
/**
 * @public
 */
export interface GetActivityTaskOutput {
    /**
     * @public
     * <p>A token that identifies the scheduled task. This token must be copied and included in
     *       subsequent calls to <a>SendTaskHeartbeat</a>, <a>SendTaskSuccess</a> or
     *         <a>SendTaskFailure</a> in order to report the progress or completion of the
     *       task.</p>
     */
    taskToken?: string;
    /**
     * @public
     * <p>The string that contains the JSON input data for the task. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    input?: string;
}
/**
 * @public
 */
export interface GetExecutionHistoryInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the execution.</p>
     */
    executionArn: string | undefined;
    /**
     * @public
     * <p>The maximum number of results that are returned per call. You can use <code>nextToken</code> to obtain further pages of results.
     *     The default is 100 and the maximum allowed page size is 1000. A value of 0 uses the default.</p>
     *          <p>This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.</p>
     */
    maxResults?: number;
    /**
     * @public
     * <p>Lists events in descending order of their <code>timeStamp</code>.</p>
     */
    reverseOrder?: boolean;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
    /**
     * @public
     * <p>You can select whether execution data (input or output of a history event) is returned.
     *       The default is <code>true</code>.</p>
     */
    includeExecutionData?: boolean;
}
/**
 * @public
 * <p>Contains details about an abort of an execution.</p>
 */
export interface ExecutionAbortedEventDetails {
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>Contains details about an execution failure event.</p>
 */
export interface ExecutionFailedEventDetails {
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>Contains details about a redriven execution.</p>
 */
export interface ExecutionRedrivenEventDetails {
    /**
     * @public
     * <p>The number of times you've redriven an execution. If you have not yet redriven an execution, the <code>redriveCount</code> is 0. This count is not updated for redrives that failed to start or are pending to be redriven.</p>
     */
    redriveCount?: number;
}
/**
 * @public
 * <p>Contains details about the start of the execution.</p>
 */
export interface ExecutionStartedEventDetails {
    /**
     * @public
     * <p>The JSON data input to the execution. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    input?: string;
    /**
     * @public
     * <p>Contains details about the input for an execution history event.</p>
     */
    inputDetails?: HistoryEventExecutionDataDetails;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role used for executing Lambda tasks.</p>
     */
    roleArn?: string;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies a state machine alias used for starting the state machine execution.</p>
     */
    stateMachineAliasArn?: string;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies a state machine version used for starting the state machine execution.</p>
     */
    stateMachineVersionArn?: string;
}
/**
 * @public
 * <p>Contains details about the successful termination of the execution.</p>
 */
export interface ExecutionSucceededEventDetails {
    /**
     * @public
     * <p>The JSON data output by the execution. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    output?: string;
    /**
     * @public
     * <p>Contains details about the output of an execution history event.</p>
     */
    outputDetails?: HistoryEventExecutionDataDetails;
}
/**
 * @public
 * <p>Contains details about the execution timeout that occurred during the execution.</p>
 */
export interface ExecutionTimedOutEventDetails {
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the timeout.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>Contains details about a Lambda function that failed during an execution.</p>
 */
export interface LambdaFunctionFailedEventDetails {
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>Contains details about the credentials that Step Functions uses for a task.</p>
 */
export interface TaskCredentials {
    /**
     * @public
     * <p>The ARN of an IAM role that Step Functions assumes for the task. The role can allow cross-account access to resources.</p>
     */
    roleArn?: string;
}
/**
 * @public
 * <p>Contains details about a Lambda function scheduled during an execution.</p>
 */
export interface LambdaFunctionScheduledEventDetails {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the scheduled Lambda function.</p>
     */
    resource: string | undefined;
    /**
     * @public
     * <p>The JSON data input to the Lambda function. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    input?: string;
    /**
     * @public
     * <p>Contains details about input for an execution history event.</p>
     */
    inputDetails?: HistoryEventExecutionDataDetails;
    /**
     * @public
     * <p>The maximum allowed duration of the Lambda function.</p>
     */
    timeoutInSeconds?: number;
    /**
     * @public
     * <p>The credentials that Step Functions uses for the task.</p>
     */
    taskCredentials?: TaskCredentials;
}
/**
 * @public
 * <p>Contains details about a failed Lambda function schedule event that occurred during an
 *       execution.</p>
 */
export interface LambdaFunctionScheduleFailedEventDetails {
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>Contains details about a lambda function that failed to start during an execution.</p>
 */
export interface LambdaFunctionStartFailedEventDetails {
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>Contains details about a Lambda function that successfully terminated during an
 *       execution.</p>
 */
export interface LambdaFunctionSucceededEventDetails {
    /**
     * @public
     * <p>The JSON data output by the Lambda function. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    output?: string;
    /**
     * @public
     * <p>Contains details about the output of an execution history event.</p>
     */
    outputDetails?: HistoryEventExecutionDataDetails;
}
/**
 * @public
 * <p>Contains details about a Lambda function timeout that occurred during an execution.</p>
 */
export interface LambdaFunctionTimedOutEventDetails {
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the timeout.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>Contains details about an iteration of a Map state.</p>
 */
export interface MapIterationEventDetails {
    /**
     * @public
     * <p>The name of the iteration’s parent Map state.</p>
     */
    name?: string;
    /**
     * @public
     * <p>The index of the array belonging to the Map state iteration.</p>
     */
    index?: number;
}
/**
 * @public
 * <p>Contains details about a Map Run failure event that occurred during a state machine execution.</p>
 */
export interface MapRunFailedEventDetails {
    /**
     * @public
     * <p>The error code of the Map Run failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>Contains details about a Map Run that was redriven.</p>
 */
export interface MapRunRedrivenEventDetails {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of a Map Run that was redriven.</p>
     */
    mapRunArn?: string;
    /**
     * @public
     * <p>The number of times the Map Run has been redriven at this point in the execution's history including this event. The redrive count for a redriven Map Run is always greater than 0.</p>
     */
    redriveCount?: number;
}
/**
 * @public
 * <p>Contains details about a Map Run that was started during a state machine execution.</p>
 */
export interface MapRunStartedEventDetails {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of a Map Run that was started.</p>
     */
    mapRunArn?: string;
}
/**
 * @public
 * <p>Details about a Map state that was started.</p>
 */
export interface MapStateStartedEventDetails {
    /**
     * @public
     * <p>The size of the array for Map state iterations.</p>
     */
    length?: number;
}
/**
 * @public
 * <p>Contains details about a state entered during an execution.</p>
 */
export interface StateEnteredEventDetails {
    /**
     * @public
     * <p>The name of the state.</p>
     */
    name: string | undefined;
    /**
     * @public
     * <p>The string that contains the JSON input data for the state. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    input?: string;
    /**
     * @public
     * <p>Contains details about the input for an execution history event.</p>
     */
    inputDetails?: HistoryEventExecutionDataDetails;
}
/**
 * @public
 * <p>Contains details about an exit from a state during an execution.</p>
 */
export interface StateExitedEventDetails {
    /**
     * @public
     * <p>The name of the state.</p>
     *          <p>A name must <i>not</i> contain:</p>
     *          <ul>
     *             <li>
     *                <p>white space</p>
     *             </li>
     *             <li>
     *                <p>brackets <code>< > \{ \} [ ]</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>wildcard characters <code>? *</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>special characters <code>" # % \ ^ | ~ ` $ & , ; : /</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p>
     *             </li>
     *          </ul>
     *          <p>To enable logging with CloudWatch Logs, the name should only contain  0-9, A-Z, a-z, - and _.</p>
     */
    name: string | undefined;
    /**
     * @public
     * <p>The JSON output data of the state. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    output?: string;
    /**
     * @public
     * <p>Contains details about the output of an execution history event.</p>
     */
    outputDetails?: HistoryEventExecutionDataDetails;
}
/**
 * @public
 * <p>Contains details about a task failure event.</p>
 */
export interface TaskFailedEventDetails {
    /**
     * @public
     * <p>The service name of the resource in a task state.</p>
     */
    resourceType: string | undefined;
    /**
     * @public
     * <p>The action of the resource called by a task state.</p>
     */
    resource: string | undefined;
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>Contains details about a task scheduled during an execution.</p>
 */
export interface TaskScheduledEventDetails {
    /**
     * @public
     * <p>The service name of the resource in a task state.</p>
     */
    resourceType: string | undefined;
    /**
     * @public
     * <p>The action of the resource called by a task state.</p>
     */
    resource: string | undefined;
    /**
     * @public
     * <p>The region of the scheduled task</p>
     */
    region: string | undefined;
    /**
     * @public
     * <p>The JSON data passed to the resource referenced in a task state.
     *       Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    parameters: string | undefined;
    /**
     * @public
     * <p>The maximum allowed duration of the task.</p>
     */
    timeoutInSeconds?: number;
    /**
     * @public
     * <p>The maximum allowed duration between two heartbeats for the task.</p>
     */
    heartbeatInSeconds?: number;
    /**
     * @public
     * <p>The credentials that Step Functions uses for the task.</p>
     */
    taskCredentials?: TaskCredentials;
}
/**
 * @public
 * <p>Contains details about the start of a task during an execution.</p>
 */
export interface TaskStartedEventDetails {
    /**
     * @public
     * <p>The service name of the resource in a task state.</p>
     */
    resourceType: string | undefined;
    /**
     * @public
     * <p>The action of the resource called by a task state.</p>
     */
    resource: string | undefined;
}
/**
 * @public
 * <p>Contains details about a task that failed to start during an execution.</p>
 */
export interface TaskStartFailedEventDetails {
    /**
     * @public
     * <p>The service name of the resource in a task state.</p>
     */
    resourceType: string | undefined;
    /**
     * @public
     * <p>The action of the resource called by a task state.</p>
     */
    resource: string | undefined;
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>Contains details about a task that failed to submit during an execution.</p>
 */
export interface TaskSubmitFailedEventDetails {
    /**
     * @public
     * <p>The service name of the resource in a task state.</p>
     */
    resourceType: string | undefined;
    /**
     * @public
     * <p>The action of the resource called by a task state.</p>
     */
    resource: string | undefined;
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 * <p>Contains details about a task submitted to a resource .</p>
 */
export interface TaskSubmittedEventDetails {
    /**
     * @public
     * <p>The service name of the resource in a task state.</p>
     */
    resourceType: string | undefined;
    /**
     * @public
     * <p>The action of the resource called by a task state.</p>
     */
    resource: string | undefined;
    /**
     * @public
     * <p>The response from a resource when a task has started. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    output?: string;
    /**
     * @public
     * <p>Contains details about the output of an execution history event.</p>
     */
    outputDetails?: HistoryEventExecutionDataDetails;
}
/**
 * @public
 * <p>Contains details about the successful completion of a task state.</p>
 */
export interface TaskSucceededEventDetails {
    /**
     * @public
     * <p>The service name of the resource in a task state.</p>
     */
    resourceType: string | undefined;
    /**
     * @public
     * <p>The action of the resource called by a task state.</p>
     */
    resource: string | undefined;
    /**
     * @public
     * <p>The full JSON response from a resource when a task has succeeded. This response becomes
     *       the output of the related task. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    output?: string;
    /**
     * @public
     * <p>Contains details about the output of an execution history event.</p>
     */
    outputDetails?: HistoryEventExecutionDataDetails;
}
/**
 * @public
 * <p>Contains details about a resource timeout that occurred during an execution.</p>
 */
export interface TaskTimedOutEventDetails {
    /**
     * @public
     * <p>The service name of the resource in a task state.</p>
     */
    resourceType: string | undefined;
    /**
     * @public
     * <p>The action of the resource called by a task state.</p>
     */
    resource: string | undefined;
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 * @enum
 */
export declare const HistoryEventType: {
    readonly ActivityFailed: "ActivityFailed";
    readonly ActivityScheduleFailed: "ActivityScheduleFailed";
    readonly ActivityScheduled: "ActivityScheduled";
    readonly ActivityStarted: "ActivityStarted";
    readonly ActivitySucceeded: "ActivitySucceeded";
    readonly ActivityTimedOut: "ActivityTimedOut";
    readonly ChoiceStateEntered: "ChoiceStateEntered";
    readonly ChoiceStateExited: "ChoiceStateExited";
    readonly ExecutionAborted: "ExecutionAborted";
    readonly ExecutionFailed: "ExecutionFailed";
    readonly ExecutionRedriven: "ExecutionRedriven";
    readonly ExecutionStarted: "ExecutionStarted";
    readonly ExecutionSucceeded: "ExecutionSucceeded";
    readonly ExecutionTimedOut: "ExecutionTimedOut";
    readonly FailStateEntered: "FailStateEntered";
    readonly LambdaFunctionFailed: "LambdaFunctionFailed";
    readonly LambdaFunctionScheduleFailed: "LambdaFunctionScheduleFailed";
    readonly LambdaFunctionScheduled: "LambdaFunctionScheduled";
    readonly LambdaFunctionStartFailed: "LambdaFunctionStartFailed";
    readonly LambdaFunctionStarted: "LambdaFunctionStarted";
    readonly LambdaFunctionSucceeded: "LambdaFunctionSucceeded";
    readonly LambdaFunctionTimedOut: "LambdaFunctionTimedOut";
    readonly MapIterationAborted: "MapIterationAborted";
    readonly MapIterationFailed: "MapIterationFailed";
    readonly MapIterationStarted: "MapIterationStarted";
    readonly MapIterationSucceeded: "MapIterationSucceeded";
    readonly MapRunAborted: "MapRunAborted";
    readonly MapRunFailed: "MapRunFailed";
    readonly MapRunRedriven: "MapRunRedriven";
    readonly MapRunStarted: "MapRunStarted";
    readonly MapRunSucceeded: "MapRunSucceeded";
    readonly MapStateAborted: "MapStateAborted";
    readonly MapStateEntered: "MapStateEntered";
    readonly MapStateExited: "MapStateExited";
    readonly MapStateFailed: "MapStateFailed";
    readonly MapStateStarted: "MapStateStarted";
    readonly MapStateSucceeded: "MapStateSucceeded";
    readonly ParallelStateAborted: "ParallelStateAborted";
    readonly ParallelStateEntered: "ParallelStateEntered";
    readonly ParallelStateExited: "ParallelStateExited";
    readonly ParallelStateFailed: "ParallelStateFailed";
    readonly ParallelStateStarted: "ParallelStateStarted";
    readonly ParallelStateSucceeded: "ParallelStateSucceeded";
    readonly PassStateEntered: "PassStateEntered";
    readonly PassStateExited: "PassStateExited";
    readonly SucceedStateEntered: "SucceedStateEntered";
    readonly SucceedStateExited: "SucceedStateExited";
    readonly TaskFailed: "TaskFailed";
    readonly TaskScheduled: "TaskScheduled";
    readonly TaskStartFailed: "TaskStartFailed";
    readonly TaskStarted: "TaskStarted";
    readonly TaskStateAborted: "TaskStateAborted";
    readonly TaskStateEntered: "TaskStateEntered";
    readonly TaskStateExited: "TaskStateExited";
    readonly TaskSubmitFailed: "TaskSubmitFailed";
    readonly TaskSubmitted: "TaskSubmitted";
    readonly TaskSucceeded: "TaskSucceeded";
    readonly TaskTimedOut: "TaskTimedOut";
    readonly WaitStateAborted: "WaitStateAborted";
    readonly WaitStateEntered: "WaitStateEntered";
    readonly WaitStateExited: "WaitStateExited";
};
/**
 * @public
 */
export type HistoryEventType = (typeof HistoryEventType)[keyof typeof HistoryEventType];
/**
 * @public
 * <p>Contains details about the events of an execution.</p>
 */
export interface HistoryEvent {
    /**
     * @public
     * <p>The date and time the event occurred.</p>
     */
    timestamp: Date | undefined;
    /**
     * @public
     * <p>The type of the event.</p>
     */
    type: HistoryEventType | undefined;
    /**
     * @public
     * <p>The id of the event. Events are numbered sequentially, starting at one.</p>
     */
    id: number | undefined;
    /**
     * @public
     * <p>The id of the previous event.</p>
     */
    previousEventId?: number;
    /**
     * @public
     * <p>Contains details about an activity that failed during an execution.</p>
     */
    activityFailedEventDetails?: ActivityFailedEventDetails;
    /**
     * @public
     * <p>Contains details about an activity schedule event that failed during an execution.</p>
     */
    activityScheduleFailedEventDetails?: ActivityScheduleFailedEventDetails;
    /**
     * @public
     * <p>Contains details about an activity scheduled during an execution.</p>
     */
    activityScheduledEventDetails?: ActivityScheduledEventDetails;
    /**
     * @public
     * <p>Contains details about the start of an activity during an execution.</p>
     */
    activityStartedEventDetails?: ActivityStartedEventDetails;
    /**
     * @public
     * <p>Contains details about an activity that successfully terminated during an
     *       execution.</p>
     */
    activitySucceededEventDetails?: ActivitySucceededEventDetails;
    /**
     * @public
     * <p>Contains details about an activity timeout that occurred during an execution.</p>
     */
    activityTimedOutEventDetails?: ActivityTimedOutEventDetails;
    /**
     * @public
     * <p>Contains details about the failure of a task.</p>
     */
    taskFailedEventDetails?: TaskFailedEventDetails;
    /**
     * @public
     * <p>Contains details about a task that was scheduled.</p>
     */
    taskScheduledEventDetails?: TaskScheduledEventDetails;
    /**
     * @public
     * <p>Contains details about a task that failed to start.</p>
     */
    taskStartFailedEventDetails?: TaskStartFailedEventDetails;
    /**
     * @public
     * <p>Contains details about a task that was started.</p>
     */
    taskStartedEventDetails?: TaskStartedEventDetails;
    /**
     * @public
     * <p>Contains details about a task that where the submit failed.</p>
     */
    taskSubmitFailedEventDetails?: TaskSubmitFailedEventDetails;
    /**
     * @public
     * <p>Contains details about a submitted task.</p>
     */
    taskSubmittedEventDetails?: TaskSubmittedEventDetails;
    /**
     * @public
     * <p>Contains details about a task that succeeded.</p>
     */
    taskSucceededEventDetails?: TaskSucceededEventDetails;
    /**
     * @public
     * <p>Contains details about a task that timed out.</p>
     */
    taskTimedOutEventDetails?: TaskTimedOutEventDetails;
    /**
     * @public
     * <p>Contains details about an execution failure event.</p>
     */
    executionFailedEventDetails?: ExecutionFailedEventDetails;
    /**
     * @public
     * <p>Contains details about the start of the execution.</p>
     */
    executionStartedEventDetails?: ExecutionStartedEventDetails;
    /**
     * @public
     * <p>Contains details about the successful termination of the execution.</p>
     */
    executionSucceededEventDetails?: ExecutionSucceededEventDetails;
    /**
     * @public
     * <p>Contains details about an abort of an execution.</p>
     */
    executionAbortedEventDetails?: ExecutionAbortedEventDetails;
    /**
     * @public
     * <p>Contains details about the execution timeout that occurred during the execution.</p>
     */
    executionTimedOutEventDetails?: ExecutionTimedOutEventDetails;
    /**
     * @public
     * <p>Contains details about the redrive attempt of an execution.</p>
     */
    executionRedrivenEventDetails?: ExecutionRedrivenEventDetails;
    /**
     * @public
     * <p>Contains details about Map state that was started.</p>
     */
    mapStateStartedEventDetails?: MapStateStartedEventDetails;
    /**
     * @public
     * <p>Contains details about an iteration of a Map state that was started.</p>
     */
    mapIterationStartedEventDetails?: MapIterationEventDetails;
    /**
     * @public
     * <p>Contains details about an iteration of a Map state that succeeded.</p>
     */
    mapIterationSucceededEventDetails?: MapIterationEventDetails;
    /**
     * @public
     * <p>Contains details about an iteration of a Map state that failed.</p>
     */
    mapIterationFailedEventDetails?: MapIterationEventDetails;
    /**
     * @public
     * <p>Contains details about an iteration of a Map state that was aborted.</p>
     */
    mapIterationAbortedEventDetails?: MapIterationEventDetails;
    /**
     * @public
     * <p>Contains details about a Lambda function that failed during an execution.</p>
     */
    lambdaFunctionFailedEventDetails?: LambdaFunctionFailedEventDetails;
    /**
     * @public
     * <p>Contains details about a failed Lambda function schedule event that occurred during an
     *       execution.</p>
     */
    lambdaFunctionScheduleFailedEventDetails?: LambdaFunctionScheduleFailedEventDetails;
    /**
     * @public
     * <p>Contains details about a Lambda function scheduled during an execution.</p>
     */
    lambdaFunctionScheduledEventDetails?: LambdaFunctionScheduledEventDetails;
    /**
     * @public
     * <p>Contains details about a lambda function that failed to start during an execution.</p>
     */
    lambdaFunctionStartFailedEventDetails?: LambdaFunctionStartFailedEventDetails;
    /**
     * @public
     * <p>Contains details about a Lambda function that terminated successfully during an
     *       execution.</p>
     */
    lambdaFunctionSucceededEventDetails?: LambdaFunctionSucceededEventDetails;
    /**
     * @public
     * <p>Contains details about a Lambda function timeout that occurred during an execution.</p>
     */
    lambdaFunctionTimedOutEventDetails?: LambdaFunctionTimedOutEventDetails;
    /**
     * @public
     * <p>Contains details about a state entered during an execution.</p>
     */
    stateEnteredEventDetails?: StateEnteredEventDetails;
    /**
     * @public
     * <p>Contains details about an exit from a state during an execution.</p>
     */
    stateExitedEventDetails?: StateExitedEventDetails;
    /**
     * @public
     * <p>Contains details, such as <code>mapRunArn</code>, and the start date and time of a Map Run. <code>mapRunArn</code> is the Amazon Resource Name (ARN) of the Map Run that was started.</p>
     */
    mapRunStartedEventDetails?: MapRunStartedEventDetails;
    /**
     * @public
     * <p>Contains error and cause details about a Map Run that failed.</p>
     */
    mapRunFailedEventDetails?: MapRunFailedEventDetails;
    /**
     * @public
     * <p>Contains details about the redrive attempt of a Map Run.</p>
     */
    mapRunRedrivenEventDetails?: MapRunRedrivenEventDetails;
}
/**
 * @public
 */
export interface GetExecutionHistoryOutput {
    /**
     * @public
     * <p>The list of events that occurred in the execution.</p>
     */
    events: HistoryEvent[] | undefined;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
}
/**
 * @public
 * <p>The provided token is not valid.</p>
 */
export declare class InvalidToken extends __BaseException {
    readonly name: "InvalidToken";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidToken, __BaseException>);
}
/**
 * @public
 */
export interface ListActivitiesInput {
    /**
     * @public
     * <p>The maximum number of results that are returned per call. You can use <code>nextToken</code> to obtain further pages of results.
     *     The default is 100 and the maximum allowed page size is 1000. A value of 0 uses the default.</p>
     *          <p>This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.</p>
     */
    maxResults?: number;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
}
/**
 * @public
 */
export interface ListActivitiesOutput {
    /**
     * @public
     * <p>The list of activities.</p>
     */
    activities: ActivityListItem[] | undefined;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
}
/**
 * @public
 * @enum
 */
export declare const ExecutionRedriveFilter: {
    readonly NOT_REDRIVEN: "NOT_REDRIVEN";
    readonly REDRIVEN: "REDRIVEN";
};
/**
 * @public
 */
export type ExecutionRedriveFilter = (typeof ExecutionRedriveFilter)[keyof typeof ExecutionRedriveFilter];
/**
 * @public
 */
export interface ListExecutionsInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine whose executions is listed.</p>
     *          <p>You can specify either a <code>mapRunArn</code> or a <code>stateMachineArn</code>, but not both.</p>
     *          <p>You can also return a list of executions associated with a specific <a href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html">alias</a> or <a href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html">version</a>, by specifying an alias ARN or a version ARN in the <code>stateMachineArn</code> parameter.</p>
     */
    stateMachineArn?: string;
    /**
     * @public
     * <p>If specified, only list the executions whose current execution status matches the given
     *       filter.</p>
     */
    statusFilter?: ExecutionStatus;
    /**
     * @public
     * <p>The maximum number of results that are returned per call. You can use <code>nextToken</code> to obtain further pages of results.
     *     The default is 100 and the maximum allowed page size is 1000. A value of 0 uses the default.</p>
     *          <p>This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.</p>
     */
    maxResults?: number;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Map Run that started the child workflow executions. If the <code>mapRunArn</code> field is specified, a list of all of the child workflow executions started by a Map Run is returned. For more information, see <a href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-examine-map-run.html">Examining Map Run</a> in the <i>Step Functions Developer Guide</i>.</p>
     *          <p>You can specify either a <code>mapRunArn</code> or a <code>stateMachineArn</code>, but not both.</p>
     */
    mapRunArn?: string;
    /**
     * @public
     * <p>Sets a filter to list executions based on whether or not they have been redriven.</p>
     *          <p>For a Distributed Map, <code>redriveFilter</code> sets a filter to list child workflow executions based on whether or not they have been redriven.</p>
     *          <p>If you do not provide a <code>redriveFilter</code>, Step Functions returns a list of both redriven and non-redriven executions.</p>
     *          <p>If you provide a state machine ARN in <code>redriveFilter</code>, the API returns a validation exception.</p>
     */
    redriveFilter?: ExecutionRedriveFilter;
}
/**
 * @public
 * <p>Contains details about an execution.</p>
 */
export interface ExecutionListItem {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the execution.</p>
     */
    executionArn: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine that ran the execution.</p>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>The name of the execution.</p>
     *          <p>A name must <i>not</i> contain:</p>
     *          <ul>
     *             <li>
     *                <p>white space</p>
     *             </li>
     *             <li>
     *                <p>brackets <code>< > \{ \} [ ]</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>wildcard characters <code>? *</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>special characters <code>" # % \ ^ | ~ ` $ & , ; : /</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p>
     *             </li>
     *          </ul>
     *          <p>To enable logging with CloudWatch Logs, the name should only contain  0-9, A-Z, a-z, - and _.</p>
     */
    name: string | undefined;
    /**
     * @public
     * <p>The current status of the execution.</p>
     */
    status: ExecutionStatus | undefined;
    /**
     * @public
     * <p>The date the execution started.</p>
     */
    startDate: Date | undefined;
    /**
     * @public
     * <p>If the execution already ended, the date the execution stopped.</p>
     */
    stopDate?: Date;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of a Map Run. This field is returned only if <code>mapRunArn</code> was specified in the <code>ListExecutions</code> API action. If <code>stateMachineArn</code> was specified in <code>ListExecutions</code>, the <code>mapRunArn</code> isn't returned.</p>
     */
    mapRunArn?: string;
    /**
     * @public
     * <p>The total number of items processed in a child workflow execution. This field is returned only if <code>mapRunArn</code> was specified in the <code>ListExecutions</code> API action. If <code>stateMachineArn</code> was specified in <code>ListExecutions</code>, the <code>itemCount</code> field isn't returned.</p>
     */
    itemCount?: number;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine version associated with the execution.</p>
     *          <p>If the state machine execution was started with an unqualified ARN, it returns null.</p>
     *          <p>If the execution was started using a <code>stateMachineAliasArn</code>, both the <code>stateMachineAliasArn</code> and <code>stateMachineVersionArn</code> parameters contain the respective values.</p>
     */
    stateMachineVersionArn?: string;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine alias used to start an execution.</p>
     *          <p>If the state machine execution was started with an unqualified ARN or a version ARN, it returns null.</p>
     */
    stateMachineAliasArn?: string;
    /**
     * @public
     * <p>The number of times you've redriven an execution. If you have not yet redriven an execution, the <code>redriveCount</code> is 0. This count is only updated when you successfully redrive an execution.</p>
     */
    redriveCount?: number;
    /**
     * @public
     * <p>The date the execution was last redriven.</p>
     */
    redriveDate?: Date;
}
/**
 * @public
 */
export interface ListExecutionsOutput {
    /**
     * @public
     * <p>The list of matching executions.</p>
     */
    executions: ExecutionListItem[] | undefined;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
}
/**
 * @public
 */
export interface ListMapRunsInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the execution for which the Map Runs must be listed.</p>
     */
    executionArn: string | undefined;
    /**
     * @public
     * <p>The maximum number of results that are returned per call. You can use <code>nextToken</code> to obtain further pages of results.
     *     The default is 100 and the maximum allowed page size is 1000. A value of 0 uses the default.</p>
     *          <p>This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.</p>
     */
    maxResults?: number;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
}
/**
 * @public
 * <p>Contains details about a specific Map Run.</p>
 */
export interface MapRunListItem {
    /**
     * @public
     * <p>The <code>executionArn</code> of the execution from which the Map Run was started.</p>
     */
    executionArn: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the Map Run.</p>
     */
    mapRunArn: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the executed state machine.</p>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>The date on which the Map Run started.</p>
     */
    startDate: Date | undefined;
    /**
     * @public
     * <p>The date on which the Map Run stopped.</p>
     */
    stopDate?: Date;
}
/**
 * @public
 */
export interface ListMapRunsOutput {
    /**
     * @public
     * <p>An array that lists information related to a Map Run, such as the Amazon Resource Name (ARN) of the Map Run and the ARN of the state machine that started the Map Run.</p>
     */
    mapRuns: MapRunListItem[] | undefined;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
}
/**
 * @public
 */
export interface ListStateMachineAliasesInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine for which you want to list aliases.</p>
     *          <p>If you specify a state machine version ARN, this API returns a list of aliases for that version.</p>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
    /**
     * @public
     * <p>The maximum number of results that are returned per call. You can use <code>nextToken</code> to obtain further pages of results.
     *     The default is 100 and the maximum allowed page size is 1000. A value of 0 uses the default.</p>
     *          <p>This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.</p>
     */
    maxResults?: number;
}
/**
 * @public
 * <p>Contains details about a specific state machine alias.</p>
 */
export interface StateMachineAliasListItem {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies a state machine alias. The alias ARN is a combination of state machine ARN and the alias name separated by a colon (:). For example, <code>stateMachineARN:PROD</code>.</p>
     */
    stateMachineAliasArn: string | undefined;
    /**
     * @public
     * <p>The creation date of a state machine alias.</p>
     */
    creationDate: Date | undefined;
}
/**
 * @public
 */
export interface ListStateMachineAliasesOutput {
    /**
     * @public
     * <p>Aliases for the state machine.</p>
     */
    stateMachineAliases: StateMachineAliasListItem[] | undefined;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
}
/**
 * @public
 */
export interface ListStateMachinesInput {
    /**
     * @public
     * <p>The maximum number of results that are returned per call. You can use <code>nextToken</code> to obtain further pages of results.
     *     The default is 100 and the maximum allowed page size is 1000. A value of 0 uses the default.</p>
     *          <p>This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.</p>
     */
    maxResults?: number;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
}
/**
 * @public
 * <p>Contains details about the state machine.</p>
 */
export interface StateMachineListItem {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the state machine.</p>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>The name of the state machine.</p>
     *          <p>A name must <i>not</i> contain:</p>
     *          <ul>
     *             <li>
     *                <p>white space</p>
     *             </li>
     *             <li>
     *                <p>brackets <code>< > \{ \} [ ]</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>wildcard characters <code>? *</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>special characters <code>" # % \ ^ | ~ ` $ & , ; : /</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p>
     *             </li>
     *          </ul>
     *          <p>To enable logging with CloudWatch Logs, the name should only contain  0-9, A-Z, a-z, - and _.</p>
     */
    name: string | undefined;
    /**
     * @public
     * <p></p>
     */
    type: StateMachineType | undefined;
    /**
     * @public
     * <p>The date the state machine is created.</p>
     */
    creationDate: Date | undefined;
}
/**
 * @public
 */
export interface ListStateMachinesOutput {
    stateMachines: StateMachineListItem[] | undefined;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
}
/**
 * @public
 */
export interface ListStateMachineVersionsInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine.</p>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
    /**
     * @public
     * <p>The maximum number of results that are returned per call. You can use <code>nextToken</code> to obtain further pages of results.
     *     The default is 100 and the maximum allowed page size is 1000. A value of 0 uses the default.</p>
     *          <p>This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.</p>
     */
    maxResults?: number;
}
/**
 * @public
 * <p>Contains details about a specific state machine version.</p>
 */
export interface StateMachineVersionListItem {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies a state machine version. The version ARN is a combination of state machine ARN and the version number separated by a colon (:). For example, <code>stateMachineARN:1</code>.</p>
     */
    stateMachineVersionArn: string | undefined;
    /**
     * @public
     * <p>The creation date of a state machine version.</p>
     */
    creationDate: Date | undefined;
}
/**
 * @public
 */
export interface ListStateMachineVersionsOutput {
    /**
     * @public
     * <p>Versions for the state machine.</p>
     */
    stateMachineVersions: StateMachineVersionListItem[] | undefined;
    /**
     * @public
     * <p>If <code>nextToken</code> is returned, there are more results available. The value of <code>nextToken</code> is a unique pagination token for each page.
     *     Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an <i>HTTP 400 InvalidToken</i> error.</p>
     */
    nextToken?: string;
}
/**
 * @public
 */
export interface ListTagsForResourceInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) for the Step Functions state machine or activity.</p>
     */
    resourceArn: string | undefined;
}
/**
 * @public
 */
export interface ListTagsForResourceOutput {
    /**
     * @public
     * <p>An array of tags associated with the resource.</p>
     */
    tags?: Tag[];
}
/**
 * @public
 */
export interface PublishStateMachineVersionInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine.</p>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>Only publish the state machine version if the current state machine's revision ID matches the specified ID.</p>
     *          <p>Use this option to avoid publishing a version if the state machine changed since you last
     *       updated it. If the specified revision ID doesn't match the state machine's current revision
     *       ID, the API returns <code>ConflictException</code>.</p>
     *          <note>
     *             <p>To specify an initial revision ID for a state machine with no revision ID assigned,
     *         specify the string <code>INITIAL</code> for the <code>revisionId</code> parameter. For
     *         example, you can specify a <code>revisionID</code> of <code>INITIAL</code> when you create a
     *         state machine using the <a>CreateStateMachine</a> API action.</p>
     *          </note>
     */
    revisionId?: string;
    /**
     * @public
     * <p>An optional description of the state machine version.</p>
     */
    description?: string;
}
/**
 * @public
 */
export interface PublishStateMachineVersionOutput {
    /**
     * @public
     * <p>The date the version was created.</p>
     */
    creationDate: Date | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) (ARN) that identifies the state machine version.</p>
     */
    stateMachineVersionArn: string | undefined;
}
/**
 * @public
 * <p>The maximum number of running executions has been reached. Running executions must end or
 *       be stopped before a new execution can be started.</p>
 */
export declare class ExecutionLimitExceeded extends __BaseException {
    readonly name: "ExecutionLimitExceeded";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ExecutionLimitExceeded, __BaseException>);
}
/**
 * @public
 * <p>The execution Amazon Resource Name (ARN) that you specified for <code>executionArn</code> cannot be redriven.</p>
 */
export declare class ExecutionNotRedrivable extends __BaseException {
    readonly name: "ExecutionNotRedrivable";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ExecutionNotRedrivable, __BaseException>);
}
/**
 * @public
 */
export interface RedriveExecutionInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the execution to be redriven.</p>
     */
    executionArn: string | undefined;
    /**
     * @public
     * <p>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency. The API will return idempotent responses for the last 10 client tokens used to successfully redrive the execution. These client tokens are valid for up to 15 minutes after they are first used.</p>
     */
    clientToken?: string;
}
/**
 * @public
 */
export interface RedriveExecutionOutput {
    /**
     * @public
     * <p>The date the execution was last redriven.</p>
     */
    redriveDate: Date | undefined;
}
/**
 * @public
 */
export interface SendTaskFailureInput {
    /**
     * @public
     * <p>The token that represents this task. Task tokens are generated by Step Functions when
     *       tasks are assigned to a worker, or in the <a href="https://docs.aws.amazon.com/step-functions/latest/dg/input-output-contextobject.html">context object</a> when a
     *       workflow enters a task state. See <a>GetActivityTaskOutput$taskToken</a>.</p>
     */
    taskToken: string | undefined;
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 */
export interface SendTaskFailureOutput {
}
/**
 * @public
 * <p>The activity does not exist.</p>
 */
export declare class TaskDoesNotExist extends __BaseException {
    readonly name: "TaskDoesNotExist";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<TaskDoesNotExist, __BaseException>);
}
/**
 * @public
 * <p>The task token has either expired or the task associated with the token has already been closed.</p>
 */
export declare class TaskTimedOut extends __BaseException {
    readonly name: "TaskTimedOut";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<TaskTimedOut, __BaseException>);
}
/**
 * @public
 */
export interface SendTaskHeartbeatInput {
    /**
     * @public
     * <p>The token that represents this task. Task tokens are generated by Step Functions when
     *       tasks are assigned to a worker, or in the <a href="https://docs.aws.amazon.com/step-functions/latest/dg/input-output-contextobject.html">context object</a> when a
     *       workflow enters a task state. See <a>GetActivityTaskOutput$taskToken</a>.</p>
     */
    taskToken: string | undefined;
}
/**
 * @public
 */
export interface SendTaskHeartbeatOutput {
}
/**
 * @public
 * <p>The provided JSON output data is not valid.</p>
 */
export declare class InvalidOutput extends __BaseException {
    readonly name: "InvalidOutput";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidOutput, __BaseException>);
}
/**
 * @public
 */
export interface SendTaskSuccessInput {
    /**
     * @public
     * <p>The token that represents this task. Task tokens are generated by Step Functions when
     *       tasks are assigned to a worker, or in the <a href="https://docs.aws.amazon.com/step-functions/latest/dg/input-output-contextobject.html">context object</a> when a
     *       workflow enters a task state. See <a>GetActivityTaskOutput$taskToken</a>.</p>
     */
    taskToken: string | undefined;
    /**
     * @public
     * <p>The JSON output of the task. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    output: string | undefined;
}
/**
 * @public
 */
export interface SendTaskSuccessOutput {
}
/**
 * @public
 * <p>The execution has the same <code>name</code> as another execution (but a different
 *         <code>input</code>).</p>
 *          <note>
 *             <p>Executions with the same <code>name</code> and <code>input</code> are considered
 *         idempotent.</p>
 *          </note>
 */
export declare class ExecutionAlreadyExists extends __BaseException {
    readonly name: "ExecutionAlreadyExists";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ExecutionAlreadyExists, __BaseException>);
}
/**
 * @public
 * <p>The provided JSON input data is not valid.</p>
 */
export declare class InvalidExecutionInput extends __BaseException {
    readonly name: "InvalidExecutionInput";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<InvalidExecutionInput, __BaseException>);
}
/**
 * @public
 */
export interface StartExecutionInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine to execute.</p>
     *          <p>The <code>stateMachineArn</code> parameter accepts one of the following inputs:</p>
     *          <ul>
     *             <li>
     *                <p>
     *                   <b>An unqualified state machine ARN</b> – Refers to a state machine ARN that isn't qualified with a version or alias ARN. The following is an example of an unqualified state machine ARN.</p>
     *                <p>
     *                   <code>arn:<partition>:states:<region>:<account-id>:stateMachine:<myStateMachine></code>
     *                </p>
     *                <p>Step Functions doesn't associate state machine executions that you start with an unqualified ARN with a version. This is true even if that version uses the same revision that the execution used.</p>
     *             </li>
     *             <li>
     *                <p>
     *                   <b>A state machine version ARN</b> – Refers to a version ARN, which is a combination of state machine ARN and the version number separated by a colon (:). The following is an example of the ARN for version 10. </p>
     *                <p>
     *                   <code>arn:<partition>:states:<region>:<account-id>:stateMachine:<myStateMachine>:10</code>
     *                </p>
     *                <p>Step Functions doesn't associate executions that you start with a version ARN with any aliases that point to that version.</p>
     *             </li>
     *             <li>
     *                <p>
     *                   <b>A state machine alias ARN</b> – Refers to an alias ARN, which is a combination of state machine ARN and the alias name separated by a colon (:). The following is an example of the ARN for an alias named <code>PROD</code>.</p>
     *                <p>
     *                   <code>arn:<partition>:states:<region>:<account-id>:stateMachine:<myStateMachine:PROD></code>
     *                </p>
     *                <p>Step Functions associates executions
     *           that you start with an alias ARN with that alias and the state machine version used for
     *           that execution.</p>
     *             </li>
     *          </ul>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>Optional name of the execution.
     *       This name must be unique for your Amazon Web Services account, Region, and state machine for 90 days. For more information,
     *     see <a href="https://docs.aws.amazon.com/step-functions/latest/dg/limits.html#service-limits-state-machine-executions">
     *     Limits Related to State Machine Executions</a> in the <i>Step Functions Developer Guide</i>.</p>
     *          <p>If you don't provide a name for the execution, Step Functions automatically generates a universally unique identifier (UUID) as the execution name.</p>
     *          <p>A name must <i>not</i> contain:</p>
     *          <ul>
     *             <li>
     *                <p>white space</p>
     *             </li>
     *             <li>
     *                <p>brackets <code>< > \{ \} [ ]</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>wildcard characters <code>? *</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>special characters <code>" # % \ ^ | ~ ` $ & , ; : /</code>
     *                </p>
     *             </li>
     *             <li>
     *                <p>control characters (<code>U+0000-001F</code>, <code>U+007F-009F</code>)</p>
     *             </li>
     *          </ul>
     *          <p>To enable logging with CloudWatch Logs, the name should only contain  0-9, A-Z, a-z, - and _.</p>
     */
    name?: string;
    /**
     * @public
     * <p>The string that contains the JSON input data for the execution, for example:</p>
     *          <p>
     *             <code>"input": "\{\"first_name\" : \"test\"\}"</code>
     *          </p>
     *          <note>
     *             <p>If you don't include any JSON input data, you still must include the two braces, for
     *         example: <code>"input": "\{\}"</code>
     *             </p>
     *          </note>
     *          <p>Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    input?: string;
    /**
     * @public
     * <p>Passes the X-Ray trace header. The trace header can also be passed in the request
     *       payload.</p>
     */
    traceHeader?: string;
}
/**
 * @public
 */
export interface StartExecutionOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the execution.</p>
     */
    executionArn: string | undefined;
    /**
     * @public
     * <p>The date the execution is started.</p>
     */
    startDate: Date | undefined;
}
/**
 * @public
 */
export interface StartSyncExecutionInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine to execute.</p>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>The name of the execution.</p>
     */
    name?: string;
    /**
     * @public
     * <p>The string that contains the JSON input data for the execution, for example:</p>
     *          <p>
     *             <code>"input": "\{\"first_name\" : \"test\"\}"</code>
     *          </p>
     *          <note>
     *             <p>If you don't include any JSON input data, you still must include the two braces, for
     *         example: <code>"input": "\{\}"</code>
     *             </p>
     *          </note>
     *          <p>Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    input?: string;
    /**
     * @public
     * <p>Passes the X-Ray trace header. The trace header can also be passed in the request
     *       payload.</p>
     */
    traceHeader?: string;
}
/**
 * @public
 * <p>An object that describes workflow billing details.</p>
 */
export interface BillingDetails {
    /**
     * @public
     * <p>Billed memory consumption of your workflow, in MB.</p>
     */
    billedMemoryUsedInMB?: number;
    /**
     * @public
     * <p>Billed duration of your workflow, in milliseconds.</p>
     */
    billedDurationInMilliseconds?: number;
}
/**
 * @public
 * @enum
 */
export declare const SyncExecutionStatus: {
    readonly FAILED: "FAILED";
    readonly SUCCEEDED: "SUCCEEDED";
    readonly TIMED_OUT: "TIMED_OUT";
};
/**
 * @public
 */
export type SyncExecutionStatus = (typeof SyncExecutionStatus)[keyof typeof SyncExecutionStatus];
/**
 * @public
 */
export interface StartSyncExecutionOutput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the execution.</p>
     */
    executionArn: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) that identifies the state machine.</p>
     */
    stateMachineArn?: string;
    /**
     * @public
     * <p>The name of the execution.</p>
     */
    name?: string;
    /**
     * @public
     * <p>The date the execution is started.</p>
     */
    startDate: Date | undefined;
    /**
     * @public
     * <p>If the execution has already ended, the date the execution stopped.</p>
     */
    stopDate: Date | undefined;
    /**
     * @public
     * <p>The current status of the execution.</p>
     */
    status: SyncExecutionStatus | undefined;
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
    /**
     * @public
     * <p>The string that contains the JSON input data of the execution. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    input?: string;
    /**
     * @public
     * <p>Provides details about execution input or output.</p>
     */
    inputDetails?: CloudWatchEventsExecutionDataDetails;
    /**
     * @public
     * <p>The JSON output data of the execution. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     *          <note>
     *             <p>This field is set only if the execution succeeds. If the execution fails, this field is
     *         null.</p>
     *          </note>
     */
    output?: string;
    /**
     * @public
     * <p>Provides details about execution input or output.</p>
     */
    outputDetails?: CloudWatchEventsExecutionDataDetails;
    /**
     * @public
     * <p>The X-Ray trace header that was passed to the execution.</p>
     */
    traceHeader?: string;
    /**
     * @public
     * <p>An object that describes workflow billing details, including billed duration and memory
     *       use.</p>
     */
    billingDetails?: BillingDetails;
}
/**
 * @public
 */
export interface StopExecutionInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the execution to stop.</p>
     */
    executionArn: string | undefined;
    /**
     * @public
     * <p>The error code of the failure.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A more detailed explanation of the cause of the failure.</p>
     */
    cause?: string;
}
/**
 * @public
 */
export interface StopExecutionOutput {
    /**
     * @public
     * <p>The date the execution is stopped.</p>
     */
    stopDate: Date | undefined;
}
/**
 * @public
 */
export interface TagResourceInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) for the Step Functions state machine or activity.</p>
     */
    resourceArn: string | undefined;
    /**
     * @public
     * <p>The list of tags to add to a resource.</p>
     *          <p>Tags may only contain Unicode letters, digits, white space, or these symbols: <code>_ . : / = + - @</code>.</p>
     */
    tags: Tag[] | undefined;
}
/**
 * @public
 */
export interface TagResourceOutput {
}
/**
 * @public
 * @enum
 */
export declare const InspectionLevel: {
    readonly DEBUG: "DEBUG";
    readonly INFO: "INFO";
    readonly TRACE: "TRACE";
};
/**
 * @public
 */
export type InspectionLevel = (typeof InspectionLevel)[keyof typeof InspectionLevel];
/**
 * @public
 */
export interface TestStateInput {
    /**
     * @public
     * <p>The <a href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-amazon-states-language.html">Amazon States Language</a> (ASL) definition of the state.</p>
     */
    definition: string | undefined;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the execution role with the required IAM permissions for the state.</p>
     */
    roleArn: string | undefined;
    /**
     * @public
     * <p>A string that contains the JSON input data for the state.</p>
     */
    input?: string;
    /**
     * @public
     * <p>Determines the values to return when a state is tested. You can specify one of the following types:</p>
     *          <ul>
     *             <li>
     *                <p>
     *                   <code>INFO</code>: Shows the final state output. By default, Step Functions sets <code>inspectionLevel</code> to <code>INFO</code> if you don't specify a level.</p>
     *             </li>
     *             <li>
     *                <p>
     *                   <code>DEBUG</code>: Shows the final state output along with the input and output data processing result.</p>
     *             </li>
     *             <li>
     *                <p>
     *                   <code>TRACE</code>: Shows the HTTP request and response for an HTTP Task. This level also shows the final state output along with the input and output data processing result.</p>
     *             </li>
     *          </ul>
     *          <p>Each of these levels also provide information about the status of the state execution and the next state to transition to.</p>
     */
    inspectionLevel?: InspectionLevel;
    /**
     * @public
     * <p>Specifies whether or not to include secret information in the test result. For HTTP Tasks, a secret includes the data that an EventBridge connection adds to modify the HTTP request headers, query parameters, and body. Step Functions doesn't omit any information included in the state definition or the HTTP response.</p>
     *          <p>If you set <code>revealSecrets</code> to <code>true</code>, you must make sure that the IAM user that calls the <code>TestState</code> API has permission for the <code>states:RevealSecrets</code> action. For an example of IAM policy that sets the <code>states:RevealSecrets</code> permission, see <a href="https://docs.aws.amazon.com/step-functions/latest/dg/test-state-isolation.html#test-state-permissions">IAM permissions to test a state</a>. Without this permission, Step Functions throws an access denied error.</p>
     *          <p>By default, <code>revealSecrets</code> is set to <code>false</code>.</p>
     */
    revealSecrets?: boolean;
}
/**
 * @public
 * <p>Contains additional details about the state's execution, including its input and output data processing flow, and HTTP request information.</p>
 */
export interface InspectionDataRequest {
    /**
     * @public
     * <p>The protocol used to make the HTTP request.</p>
     */
    protocol?: string;
    /**
     * @public
     * <p>The HTTP method used for the HTTP request.</p>
     */
    method?: string;
    /**
     * @public
     * <p>The API endpoint used for the HTTP request.</p>
     */
    url?: string;
    /**
     * @public
     * <p>The request headers associated with the HTTP request.</p>
     */
    headers?: string;
    /**
     * @public
     * <p>The request body for the HTTP request.</p>
     */
    body?: string;
}
/**
 * @public
 * <p>Contains additional details about the state's execution, including its input and output data processing flow, and HTTP response information. The <code>inspectionLevel</code> request parameter specifies which details are returned.</p>
 */
export interface InspectionDataResponse {
    /**
     * @public
     * <p>The protocol used to return the HTTP response.</p>
     */
    protocol?: string;
    /**
     * @public
     * <p>The HTTP response status code for the HTTP response.</p>
     */
    statusCode?: string;
    /**
     * @public
     * <p>The message associated with the HTTP status code.</p>
     */
    statusMessage?: string;
    /**
     * @public
     * <p>The response headers associated with the HTTP response.</p>
     */
    headers?: string;
    /**
     * @public
     * <p>The HTTP response returned.</p>
     */
    body?: string;
}
/**
 * @public
 * <p>Contains additional details about the state's execution, including its input and output data processing flow, and HTTP request and response information.</p>
 */
export interface InspectionData {
    /**
     * @public
     * <p>The raw state input.</p>
     */
    input?: string;
    /**
     * @public
     * <p>The input after Step Functions applies the <a href="https://docs.aws.amazon.com/step-functions/latest/dg/input-output-inputpath-params.html#input-output-inputpath">InputPath</a> filter.</p>
     */
    afterInputPath?: string;
    /**
     * @public
     * <p>The effective input after Step Functions applies the <a href="https://docs.aws.amazon.com/step-functions/latest/dg/input-output-inputpath-params.html#input-output-parameters">Parameters</a> filter.</p>
     */
    afterParameters?: string;
    /**
     * @public
     * <p>The state's raw result.</p>
     */
    result?: string;
    /**
     * @public
     * <p>The effective result after Step Functions applies the <a href="https://docs.aws.amazon.com/step-functions/latest/dg/input-output-inputpath-params.html#input-output-resultselector">ResultSelector</a> filter.</p>
     */
    afterResultSelector?: string;
    /**
     * @public
     * <p>The effective result combined with the raw state input after Step Functions applies the <a href="https://docs.aws.amazon.com/step-functions/latest/dg/input-output-resultpath.html">ResultPath</a> filter.</p>
     */
    afterResultPath?: string;
    /**
     * @public
     * <p>The raw HTTP request that is sent when you test an HTTP Task.</p>
     */
    request?: InspectionDataRequest;
    /**
     * @public
     * <p>The raw HTTP response that is returned when you test an HTTP Task.</p>
     */
    response?: InspectionDataResponse;
}
/**
 * @public
 * @enum
 */
export declare const TestExecutionStatus: {
    readonly CAUGHT_ERROR: "CAUGHT_ERROR";
    readonly FAILED: "FAILED";
    readonly RETRIABLE: "RETRIABLE";
    readonly SUCCEEDED: "SUCCEEDED";
};
/**
 * @public
 */
export type TestExecutionStatus = (typeof TestExecutionStatus)[keyof typeof TestExecutionStatus];
/**
 * @public
 */
export interface TestStateOutput {
    /**
     * @public
     * <p>The JSON output data of the state. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.</p>
     */
    output?: string;
    /**
     * @public
     * <p>The error returned when the execution of a state fails.</p>
     */
    error?: string;
    /**
     * @public
     * <p>A detailed explanation of the cause for the error when the execution of a state fails.</p>
     */
    cause?: string;
    /**
     * @public
     * <p>Returns additional details about the state's execution, including its input and output data processing flow, and HTTP request and response information. The <code>inspectionLevel</code> request parameter specifies which details are returned.</p>
     */
    inspectionData?: InspectionData;
    /**
     * @public
     * <p>The name of the next state to transition to. If you haven't defined a next state in your definition or if the execution of the state fails, this ﬁeld doesn't contain a value.</p>
     */
    nextState?: string;
    /**
     * @public
     * <p>The execution status of the state.</p>
     */
    status?: TestExecutionStatus;
}
/**
 * @public
 */
export interface UntagResourceInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) for the Step Functions state machine or activity.</p>
     */
    resourceArn: string | undefined;
    /**
     * @public
     * <p>The list of tags to remove from the resource.</p>
     */
    tagKeys: string[] | undefined;
}
/**
 * @public
 */
export interface UntagResourceOutput {
}
/**
 * @public
 */
export interface UpdateMapRunInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of a Map Run.</p>
     */
    mapRunArn: string | undefined;
    /**
     * @public
     * <p>The maximum number of child workflow executions that can be specified to run in parallel for the Map Run at the same time.</p>
     */
    maxConcurrency?: number;
    /**
     * @public
     * <p>The maximum percentage of failed items before the Map Run fails.</p>
     */
    toleratedFailurePercentage?: number;
    /**
     * @public
     * <p>The maximum number of failed items before the Map Run fails.</p>
     */
    toleratedFailureCount?: number;
}
/**
 * @public
 */
export interface UpdateMapRunOutput {
}
/**
 * @public
 * <p>Request is missing a required parameter. This error occurs if both <code>definition</code>
 *       and <code>roleArn</code> are not specified.</p>
 */
export declare class MissingRequiredParameter extends __BaseException {
    readonly name: "MissingRequiredParameter";
    readonly $fault: "client";
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<MissingRequiredParameter, __BaseException>);
}
/**
 * @public
 */
export interface UpdateStateMachineInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine.</p>
     */
    stateMachineArn: string | undefined;
    /**
     * @public
     * <p>The Amazon States Language definition of the state machine. See <a href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-amazon-states-language.html">Amazon States Language</a>.</p>
     */
    definition?: string;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the IAM role of the state machine.</p>
     */
    roleArn?: string;
    /**
     * @public
     * <p>Use the <code>LoggingConfiguration</code> data type to set CloudWatch Logs
     *       options.</p>
     */
    loggingConfiguration?: LoggingConfiguration;
    /**
     * @public
     * <p>Selects whether X-Ray tracing is enabled.</p>
     */
    tracingConfiguration?: TracingConfiguration;
    /**
     * @public
     * <p>Specifies whether the state machine version is published. The default is
     *         <code>false</code>. To publish a version after updating the state machine, set
     *         <code>publish</code> to <code>true</code>.</p>
     */
    publish?: boolean;
    /**
     * @public
     * <p>An optional description of the state machine version to publish.</p>
     *          <p>You can only specify the <code>versionDescription</code> parameter if you've set <code>publish</code> to <code>true</code>.</p>
     */
    versionDescription?: string;
}
/**
 * @public
 */
export interface UpdateStateMachineOutput {
    /**
     * @public
     * <p>The date and time the state machine was updated.</p>
     */
    updateDate: Date | undefined;
    /**
     * @public
     * <p>The revision identifier for the updated state machine.</p>
     */
    revisionId?: string;
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the published state machine version.</p>
     *          <p>If the <code>publish</code> parameter isn't set to <code>true</code>, this field returns null.</p>
     */
    stateMachineVersionArn?: string;
}
/**
 * @public
 */
export interface UpdateStateMachineAliasInput {
    /**
     * @public
     * <p>The Amazon Resource Name (ARN) of the state machine alias.</p>
     */
    stateMachineAliasArn: string | undefined;
    /**
     * @public
     * <p>A description of the state machine alias.</p>
     */
    description?: string;
    /**
     * @public
     * <p>The routing configuration of the state machine alias.</p>
     *          <p>An array of <code>RoutingConfig</code> objects that specifies up to two state machine versions that the alias starts executions for.</p>
     */
    routingConfiguration?: RoutingConfigurationListItem[];
}
/**
 * @public
 */
export interface UpdateStateMachineAliasOutput {
    /**
     * @public
     * <p>The date and time the state machine alias was updated.</p>
     */
    updateDate: Date | undefined;
}
/**
 * @internal
 */
export declare const ActivityFailedEventDetailsFilterSensitiveLog: (obj: ActivityFailedEventDetails) => any;
/**
 * @internal
 */
export declare const ActivityScheduledEventDetailsFilterSensitiveLog: (obj: ActivityScheduledEventDetails) => any;
/**
 * @internal
 */
export declare const ActivityScheduleFailedEventDetailsFilterSensitiveLog: (obj: ActivityScheduleFailedEventDetails) => any;
/**
 * @internal
 */
export declare const ActivitySucceededEventDetailsFilterSensitiveLog: (obj: ActivitySucceededEventDetails) => any;
/**
 * @internal
 */
export declare const ActivityTimedOutEventDetailsFilterSensitiveLog: (obj: ActivityTimedOutEventDetails) => any;
/**
 * @internal
 */
export declare const CreateStateMachineInputFilterSensitiveLog: (obj: CreateStateMachineInput) => any;
/**
 * @internal
 */
export declare const CreateStateMachineAliasInputFilterSensitiveLog: (obj: CreateStateMachineAliasInput) => any;
/**
 * @internal
 */
export declare const DescribeExecutionOutputFilterSensitiveLog: (obj: DescribeExecutionOutput) => any;
/**
 * @internal
 */
export declare const DescribeStateMachineOutputFilterSensitiveLog: (obj: DescribeStateMachineOutput) => any;
/**
 * @internal
 */
export declare const DescribeStateMachineAliasOutputFilterSensitiveLog: (obj: DescribeStateMachineAliasOutput) => any;
/**
 * @internal
 */
export declare const DescribeStateMachineForExecutionOutputFilterSensitiveLog: (obj: DescribeStateMachineForExecutionOutput) => any;
/**
 * @internal
 */
export declare const GetActivityTaskOutputFilterSensitiveLog: (obj: GetActivityTaskOutput) => any;
/**
 * @internal
 */
export declare const ExecutionAbortedEventDetailsFilterSensitiveLog: (obj: ExecutionAbortedEventDetails) => any;
/**
 * @internal
 */
export declare const ExecutionFailedEventDetailsFilterSensitiveLog: (obj: ExecutionFailedEventDetails) => any;
/**
 * @internal
 */
export declare const ExecutionStartedEventDetailsFilterSensitiveLog: (obj: ExecutionStartedEventDetails) => any;
/**
 * @internal
 */
export declare const ExecutionSucceededEventDetailsFilterSensitiveLog: (obj: ExecutionSucceededEventDetails) => any;
/**
 * @internal
 */
export declare const ExecutionTimedOutEventDetailsFilterSensitiveLog: (obj: ExecutionTimedOutEventDetails) => any;
/**
 * @internal
 */
export declare const LambdaFunctionFailedEventDetailsFilterSensitiveLog: (obj: LambdaFunctionFailedEventDetails) => any;
/**
 * @internal
 */
export declare const LambdaFunctionScheduledEventDetailsFilterSensitiveLog: (obj: LambdaFunctionScheduledEventDetails) => any;
/**
 * @internal
 */
export declare const LambdaFunctionScheduleFailedEventDetailsFilterSensitiveLog: (obj: LambdaFunctionScheduleFailedEventDetails) => any;
/**
 * @internal
 */
export declare const LambdaFunctionStartFailedEventDetailsFilterSensitiveLog: (obj: LambdaFunctionStartFailedEventDetails) => any;
/**
 * @internal
 */
export declare const LambdaFunctionSucceededEventDetailsFilterSensitiveLog: (obj: LambdaFunctionSucceededEventDetails) => any;
/**
 * @internal
 */
export declare const LambdaFunctionTimedOutEventDetailsFilterSensitiveLog: (obj: LambdaFunctionTimedOutEventDetails) => any;
/**
 * @internal
 */
export declare const MapRunFailedEventDetailsFilterSensitiveLog: (obj: MapRunFailedEventDetails) => any;
/**
 * @internal
 */
export declare const StateEnteredEventDetailsFilterSensitiveLog: (obj: StateEnteredEventDetails) => any;
/**
 * @internal
 */
export declare const StateExitedEventDetailsFilterSensitiveLog: (obj: StateExitedEventDetails) => any;
/**
 * @internal
 */
export declare const TaskFailedEventDetailsFilterSensitiveLog: (obj: TaskFailedEventDetails) => any;
/**
 * @internal
 */
export declare const TaskScheduledEventDetailsFilterSensitiveLog: (obj: TaskScheduledEventDetails) => any;
/**
 * @internal
 */
export declare const TaskStartFailedEventDetailsFilterSensitiveLog: (obj: TaskStartFailedEventDetails) => any;
/**
 * @internal
 */
export declare const TaskSubmitFailedEventDetailsFilterSensitiveLog: (obj: TaskSubmitFailedEventDetails) => any;
/**
 * @internal
 */
export declare const TaskSubmittedEventDetailsFilterSensitiveLog: (obj: TaskSubmittedEventDetails) => any;
/**
 * @internal
 */
export declare const TaskSucceededEventDetailsFilterSensitiveLog: (obj: TaskSucceededEventDetails) => any;
/**
 * @internal
 */
export declare const TaskTimedOutEventDetailsFilterSensitiveLog: (obj: TaskTimedOutEventDetails) => any;
/**
 * @internal
 */
export declare const HistoryEventFilterSensitiveLog: (obj: HistoryEvent) => any;
/**
 * @internal
 */
export declare const GetExecutionHistoryOutputFilterSensitiveLog: (obj: GetExecutionHistoryOutput) => any;
/**
 * @internal
 */
export declare const PublishStateMachineVersionInputFilterSensitiveLog: (obj: PublishStateMachineVersionInput) => any;
/**
 * @internal
 */
export declare const SendTaskFailureInputFilterSensitiveLog: (obj: SendTaskFailureInput) => any;
/**
 * @internal
 */
export declare const SendTaskSuccessInputFilterSensitiveLog: (obj: SendTaskSuccessInput) => any;
/**
 * @internal
 */
export declare const StartExecutionInputFilterSensitiveLog: (obj: StartExecutionInput) => any;
/**
 * @internal
 */
export declare const StartSyncExecutionInputFilterSensitiveLog: (obj: StartSyncExecutionInput) => any;
/**
 * @internal
 */
export declare const StartSyncExecutionOutputFilterSensitiveLog: (obj: StartSyncExecutionOutput) => any;
/**
 * @internal
 */
export declare const StopExecutionInputFilterSensitiveLog: (obj: StopExecutionInput) => any;
/**
 * @internal
 */
export declare const TestStateInputFilterSensitiveLog: (obj: TestStateInput) => any;
/**
 * @internal
 */
export declare const InspectionDataFilterSensitiveLog: (obj: InspectionData) => any;
/**
 * @internal
 */
export declare const TestStateOutputFilterSensitiveLog: (obj: TestStateOutput) => any;
/**
 * @internal
 */
export declare const UpdateStateMachineInputFilterSensitiveLog: (obj: UpdateStateMachineInput) => any;
/**
 * @internal
 */
export declare const UpdateStateMachineAliasInputFilterSensitiveLog: (obj: UpdateStateMachineAliasInput) => any;
